@@ -55,13 +55,13 @@ namespace Digikam
 {
 
 template <class A>
-static inline A* currentAlbum(QItemSelectionModel *selModel, AlbumFilterModel *filterModel)
+static inline A* currentAlbum(QItemSelectionModel* selModel, AlbumFilterModel* filterModel)
 {
     return static_cast<A*>(filterModel->albumForIndex(selModel->currentIndex()));
 }
 
 template <class A>
-static QList<A*> selectedAlbums(QItemSelectionModel *selModel, AlbumFilterModel *filterModel)
+static QList<A*> selectedAlbums(QItemSelectionModel* selModel, AlbumFilterModel* filterModel)
 {
     QList<QModelIndex> indexes = selModel->selectedIndexes();
     QList<A*> albums;
@@ -86,9 +86,9 @@ struct State
 class AlbumTreeViewDelegate : public QStyledItemDelegate
 {
 public:
-    AlbumTreeViewDelegate(AbstractAlbumTreeView *treeView = 0)
-                : QStyledItemDelegate(treeView),
-                  m_treeView(treeView), m_height(0)
+    AlbumTreeViewDelegate(AbstractAlbumTreeView* treeView = 0)
+        : QStyledItemDelegate(treeView),
+          m_treeView(treeView), m_height(0)
     {
         updateHeight();
     }
@@ -103,22 +103,29 @@ public:
     void updateHeight()
     {
         int h = qMax(AlbumThumbnailLoader::instance()->thumbnailSize() + 2, m_treeView->fontMetrics().height());
+
         if (h % 2 > 0)
+        {
             ++h;
+        }
+
         setHeight(h);
     }
 
     void setHeight(int height)
     {
         if (m_height == height)
+        {
             return;
+        }
+
         m_height = height;
         emit sizeHintChanged(QModelIndex());
     }
 
 protected:
 
-    AbstractAlbumTreeView *m_treeView;
+    AbstractAlbumTreeView* m_treeView;
     int m_height;
 };
 
@@ -138,7 +145,7 @@ public:
     {
     }
 
-    AlbumTreeViewDelegate *delegate;
+    AlbumTreeViewDelegate* delegate;
 
     bool expandOnSingleClick;
     bool expandNewCurrent;
@@ -156,7 +163,7 @@ public:
     static const QString configSortColumnEntry;
     static const QString configSortOrderEntry;
 
-    QTimer       *resizeColumnsTimer;
+    QTimer*       resizeColumnsTimer;
 
     AlbumPointer<Album>  lastSelectedAlbum;
 
@@ -169,7 +176,7 @@ const QString AbstractAlbumTreeViewPriv::configSortOrderEntry("SortOrder");
 
 // --------------------------------------------------------
 
-AbstractAlbumTreeView::AbstractAlbumTreeView(AbstractSpecificAlbumModel *model, AlbumFilterModel *filterModel, QWidget *parent)
+AbstractAlbumTreeView::AbstractAlbumTreeView(AbstractSpecificAlbumModel* model, AlbumFilterModel* filterModel, QWidget* parent)
     : QTreeView(parent), StateSavingObject(this),
       m_albumModel(0), m_albumFilterModel(0),
       d(new AbstractAlbumTreeViewPriv)
@@ -189,16 +196,18 @@ AbstractAlbumTreeView::AbstractAlbumTreeView(AbstractSpecificAlbumModel *model,
     m_albumModel       = model;
 
     if (filterModel)
+    {
         setAlbumFilterModel(filterModel);
+    }
 
     if (!m_albumModel->rootAlbum())
     {
         connect(m_albumModel, SIGNAL(rootAlbumAvailable()),
-                 this, SLOT(slotRootAlbumAvailable()));
+                this, SLOT(slotRootAlbumAvailable()));
     }
 
     connect(AlbumSettings::instance(), SIGNAL(setupChanged()),
-             this, SLOT(albumSettingsChanged()));
+            this, SLOT(albumSettingsChanged()));
     connect(this, SIGNAL(currentAlbumChanged(Album*)),
             this, SLOT(currentAlbumChangedForBackupSelection(Album*)));
 
@@ -209,10 +218,12 @@ AbstractAlbumTreeView::~AbstractAlbumTreeView()
     delete d;
 }
 
-void AbstractAlbumTreeView::setAlbumFilterModel(AlbumFilterModel *filterModel)
+void AbstractAlbumTreeView::setAlbumFilterModel(AlbumFilterModel* filterModel)
 {
     if (filterModel == m_albumFilterModel)
+    {
         return;
+    }
 
     if (m_albumFilterModel)
     {
@@ -228,17 +239,17 @@ void AbstractAlbumTreeView::setAlbumFilterModel(AlbumFilterModel *filterModel)
     m_albumFilterModel->setSourceAlbumModel(m_albumModel);
 
     connect(m_albumFilterModel, SIGNAL(searchTextSettingsAboutToChange(bool, bool)),
-             this, SLOT(slotSearchTextSettingsAboutToChange(bool, bool)));
+            this, SLOT(slotSearchTextSettingsAboutToChange(bool, bool)));
     connect(m_albumFilterModel, SIGNAL(searchTextSettingsChanged(bool, bool)),
-             this, SLOT(slotSearchTextSettingsChanged(bool, bool)));
+            this, SLOT(slotSearchTextSettingsChanged(bool, bool)));
 
     setModel(m_albumFilterModel);
 
-    connect(selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex &)),
-             this, SLOT(slotCurrentChanged()));
+    connect(selectionModel(), SIGNAL(currentChanged(const QModelIndex&, const QModelIndex&)),
+            this, SLOT(slotCurrentChanged()));
 
-    connect(selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection &)),
-             this, SLOT(slotCurrentChanged()));
+    connect(selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
+            this, SLOT(slotCurrentChanged()));
 
     connect(m_albumFilterModel, SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)),
             this, SLOT(adaptColumnsOnDataChange(const QModelIndex&, const QModelIndex&)));
@@ -252,12 +263,12 @@ void AbstractAlbumTreeView::setAlbumFilterModel(AlbumFilterModel *filterModel)
 
 }
 
-AbstractSpecificAlbumModel *AbstractAlbumTreeView::albumModel() const
+AbstractSpecificAlbumModel* AbstractAlbumTreeView::albumModel() const
 {
     return m_albumModel;
 }
 
-AlbumFilterModel *AbstractAlbumTreeView::albumFilterModel() const
+AlbumFilterModel* AbstractAlbumTreeView::albumFilterModel() const
 {
     return m_albumFilterModel;
 }
@@ -279,11 +290,16 @@ void AbstractAlbumTreeView::setSelectAlbumOnClick(bool selectOnClick)
 
 QModelIndex AbstractAlbumTreeView::indexVisuallyAt(const QPoint& p)
 {
-    if (viewport()->rect().contains(p)) {
+    if (viewport()->rect().contains(p))
+    {
         QModelIndex index = indexAt(p);
+
         if (index.isValid() && visualRect(index).contains(p))
+        {
             return index;
+        }
     }
+
     return QModelIndex();
 }
 
@@ -301,14 +317,14 @@ void AbstractAlbumTreeView::slotSearchTextSettingsAboutToChange(bool searched, b
 
         // selection is ignored here because the user may have changed this
         // while searching
-        foreach (const int &expandedId, expansion)
+        foreach (const int& expandedId, expansion)
         {
             d->searchBackup[expandedId].expanded = true;
         }
 
         // also backup the last selected album in case this didn't work via the
         // slot
-        Album *current = currentAlbum<Album>(selectionModel(), m_albumFilterModel);
+        Album* current = currentAlbum<Album>(selectionModel(), m_albumFilterModel);
         d->lastSelectedAlbum = current;
 
     }
@@ -349,7 +365,7 @@ void AbstractAlbumTreeView::slotSearchTextSettingsChanged(bool wasSearching, boo
 
 }
 
-void AbstractAlbumTreeView::currentAlbumChangedForBackupSelection(Album *currentAlbum)
+void AbstractAlbumTreeView::currentAlbumChangedForBackupSelection(Album* currentAlbum)
 {
     d->lastSelectedAlbum = currentAlbum;
 }
@@ -366,18 +382,24 @@ bool AbstractAlbumTreeView::expandMatches(const QModelIndex& index)
     // expand index if a child matches
     QModelIndex source_index = m_albumFilterModel->mapToSource(index);
     AlbumFilterModel::MatchResult result = m_albumFilterModel->matchResult(source_index);
+
     if (result == AlbumFilterModel::ChildMatch || result == AlbumFilterModel::SpecialMatch)
+    {
         expand(index);
+    }
+
     anyMatch = result;
 
     // expand children if they have a (indirect) match
     int rows = m_albumFilterModel->rowCount(index);
+
     for (int i = 0; i < rows; ++i)
     {
         QModelIndex child = m_albumFilterModel->index(i, 0, index);
         bool childResult = expandMatches(child);
         anyMatch = anyMatch || childResult;
     }
+
     return anyMatch;
 }
 
@@ -391,9 +413,10 @@ void AbstractAlbumTreeView::setAlbumManagerCurrentAlbum(bool set)
     d->setInAlbumManager = set;
 }
 
-void AbstractAlbumTreeView::slotSelectAlbum(Album *album, bool selectInAlbumManager)
+void AbstractAlbumTreeView::slotSelectAlbum(Album* album, bool selectInAlbumManager)
 {
     setCurrentIndex(albumFilterModel()->indexForAlbum(album));
+
     // check local and global flag
     if (selectInAlbumManager && d->setInAlbumManager)
     {
@@ -411,15 +434,17 @@ void AbstractAlbumTreeView::slotSelectionChanged()
     emit selectedAlbumsChanged(selectedAlbums<Album>(selectionModel(), m_albumFilterModel));
 }
 
-void AbstractAlbumTreeView::mousePressEvent(QMouseEvent *e)
+void AbstractAlbumTreeView::mousePressEvent(QMouseEvent* e)
 {
 
     if (d->selectAlbumOnClick && e->button() == Qt::LeftButton)
     {
         QModelIndex index = indexVisuallyAt(e->pos());
+
         if (index.isValid())
         {
-            Album *album = albumFilterModel()->albumForIndex(index);
+            Album* album = albumFilterModel()->albumForIndex(index);
+
             if (album && d->setInAlbumManager)
             {
                 AlbumManager::instance()->setCurrentAlbum(album);
@@ -430,6 +455,7 @@ void AbstractAlbumTreeView::mousePressEvent(QMouseEvent *e)
     if ((d->expandOnSingleClick || d->expandNewCurrent) && e->button() == Qt::LeftButton)
     {
         QModelIndex index = indexVisuallyAt(e->pos());
+
         if (index.isValid())
         {
             if (d->expandOnSingleClick)
@@ -437,27 +463,35 @@ void AbstractAlbumTreeView::mousePressEvent(QMouseEvent *e)
                 // See B.K.O #126871: collapse/expand treeview using left mouse button single click.
                 // Exception: If a newly selected item is already expanded, do not collapse on selection.
                 bool expanded = isExpanded(index);
+
                 if (index == currentIndex() || !expanded)
+                {
                     setExpanded(index, !expanded);
+                }
             }
             else
             {
                 if (index != currentIndex())
+                {
                     expand(index);
+                }
             }
         }
     }
     else if (m_checkOnMiddleClick && e->button() == Qt::MidButton)
     {
-        Album *a = m_albumFilterModel->albumForIndex(indexAt(e->pos()));
+        Album* a = m_albumFilterModel->albumForIndex(indexAt(e->pos()));
+
         if (a)
+        {
             middleButtonPressed(a);
+        }
     }
 
     QTreeView::mousePressEvent(e);
 }
 
-void AbstractAlbumTreeView::middleButtonPressed(Album *)
+void AbstractAlbumTreeView::middleButtonPressed(Album*)
 {
     // reimplement if needed
 }
@@ -465,14 +499,20 @@ void AbstractAlbumTreeView::middleButtonPressed(Album *)
 void AbstractAlbumTreeView::startDrag(Qt::DropActions supportedActions)
 {
     QModelIndexList indexes = selectedIndexes();
-    if (indexes.count() > 0) {
-        QMimeData *data = m_albumFilterModel->mimeData(indexes);
+
+    if (indexes.count() > 0)
+    {
+        QMimeData* data = m_albumFilterModel->mimeData(indexes);
+
         if (!data)
+        {
             return;
+        }
+
         QStyleOptionViewItem option = viewOptions();
         option.rect = viewport()->rect();
         QPixmap pixmap = /*m_delegate->*/pixmapForDrag(option, indexes);
-        QDrag *drag = new QDrag(this);
+        QDrag* drag = new QDrag(this);
         drag->setPixmap(pixmap);
         drag->setMimeData(data);
         drag->exec(supportedActions, Qt::IgnoreAction);
@@ -484,34 +524,43 @@ void AbstractAlbumTreeView::startDrag(Qt::DropActions supportedActions)
 QPixmap AbstractAlbumTreeView::pixmapForDrag(const QStyleOptionViewItem&, QList<QModelIndex> indexes)
 {
     if (indexes.isEmpty())
+    {
         return QPixmap();
+    }
 
     QVariant decoration = indexes.first().data(Qt::DecorationRole);
     return decoration.value<QPixmap>();
 }
 
-void AbstractAlbumTreeView::dragEnterEvent(QDragEnterEvent *e)
+void AbstractAlbumTreeView::dragEnterEvent(QDragEnterEvent* e)
 {
-    AlbumModelDragDropHandler *handler = m_albumModel->dragDropHandler();
+    AlbumModelDragDropHandler* handler = m_albumModel->dragDropHandler();
+
     if (handler && handler->acceptsMimeData(e->mimeData()))
     {
         setState(DraggingState);
         e->accept();
     }
     else
+    {
         e->ignore();
+    }
 }
 
-void AbstractAlbumTreeView::dragMoveEvent(QDragMoveEvent *e)
+void AbstractAlbumTreeView::dragMoveEvent(QDragMoveEvent* e)
 {
     QTreeView::dragMoveEvent(e);
-    AlbumModelDragDropHandler *handler = m_albumModel->dragDropHandler();
+    AlbumModelDragDropHandler* handler = m_albumModel->dragDropHandler();
+
     if (handler)
     {
         QModelIndex index = indexVisuallyAt(e->pos());
         Qt::DropAction action = handler->accepts(e, m_albumFilterModel->mapToSourceAlbumModel(index));
+
         if (action == Qt::IgnoreAction)
+        {
             e->ignore();
+        }
         else
         {
             e->setDropAction(action);
@@ -520,20 +569,24 @@ void AbstractAlbumTreeView::dragMoveEvent(QDragMoveEvent *e)
     }
 }
 
-void AbstractAlbumTreeView::dragLeaveEvent(QDragLeaveEvent * e)
+void AbstractAlbumTreeView::dragLeaveEvent(QDragLeaveEvent* e)
 {
     QTreeView::dragLeaveEvent(e);
 }
 
-void AbstractAlbumTreeView::dropEvent(QDropEvent *e)
+void AbstractAlbumTreeView::dropEvent(QDropEvent* e)
 {
     QTreeView::dropEvent(e);
-    AlbumModelDragDropHandler *handler = m_albumModel->dragDropHandler();
+    AlbumModelDragDropHandler* handler = m_albumModel->dragDropHandler();
+
     if (handler)
     {
         QModelIndex index = indexVisuallyAt(e->pos());
+
         if (handler->dropEvent(this, e, m_albumFilterModel->mapToSourceAlbumModel(index)))
+        {
             e->accept();
+        }
     }
 }
 
@@ -546,12 +599,13 @@ void AbstractAlbumTreeView::doLoadState()
 
     // extract the selection from the config
     const QStringList selection = configGroup.readEntry(entryName(d->configSelectionEntry),
-                    QStringList());
+                                  QStringList());
     //kDebug() << "selection: " << selection;
-    foreach(const QString &key, selection)
+    foreach (const QString& key, selection)
     {
         bool validId;
         int id = key.toInt(&validId);
+
         if (validId)
         {
             d->statesByAlbumId[id].selected = true;
@@ -560,12 +614,13 @@ void AbstractAlbumTreeView::doLoadState()
 
     // extract expansion state from config
     const QStringList expansion = configGroup.readEntry(entryName(d->configExpansionEntry),
-                    QStringList());
+                                  QStringList());
     //kDebug() << "expansion: " << expansion;
-    foreach(const QString &key, expansion)
+    foreach (const QString& key, expansion)
     {
         bool validId;
         int id = key.toInt(&validId);
+
         if (validId)
         {
             d->statesByAlbumId[id].expanded = true;
@@ -577,6 +632,7 @@ void AbstractAlbumTreeView::doLoadState()
     //kDebug() << "currentIndex: " << key;
     bool validId;
     const int id = key.toInt(&validId);
+
     if (validId)
     {
         d->statesByAlbumId[id].currentIndex = true;
@@ -603,7 +659,7 @@ void AbstractAlbumTreeView::doLoadState()
                  (Qt::SortOrder) configGroup.readEntry(entryName(d->configSortOrderEntry), (int) Qt::AscendingOrder));
 
     // use a timer to scroll to the first possible selected album
-    QTimer *selectCurrentTimer = new QTimer(this);
+    QTimer* selectCurrentTimer = new QTimer(this);
     selectCurrentTimer->setInterval(200);
     selectCurrentTimer->setSingleShot(true);
     connect(selectCurrentTimer, SIGNAL(timeout()),
@@ -611,9 +667,10 @@ void AbstractAlbumTreeView::doLoadState()
 
 }
 
-void AbstractAlbumTreeView::restoreStateForHierarchy(const QModelIndex &index, QMap<int, Digikam::State> &stateStore)
+void AbstractAlbumTreeView::restoreStateForHierarchy(const QModelIndex& index, QMap<int, Digikam::State> &stateStore)
 {
     restoreState(index, stateStore);
+
     // do a recursive call of the state restoration
     for (int i = 0; i < model()->rowCount(index); ++i)
     {
@@ -622,9 +679,10 @@ void AbstractAlbumTreeView::restoreStateForHierarchy(const QModelIndex &index, Q
     }
 }
 
-void AbstractAlbumTreeView::restoreState(const QModelIndex &index, QMap<int, Digikam::State> &stateStore)
+void AbstractAlbumTreeView::restoreState(const QModelIndex& index, QMap<int, Digikam::State> &stateStore)
 {
-    Album *album = albumFilterModel()->albumForIndex(index);
+    Album* album = albumFilterModel()->albumForIndex(index);
+
     if (album && stateStore.contains(album->id()))
     {
 
@@ -640,7 +698,7 @@ void AbstractAlbumTreeView::restoreState(const QModelIndex &index, QMap<int, Dig
         {
             //kDebug() << "Selecting" << album->title();
             selectionModel()->select(index, QItemSelectionModel::SelectCurrent
-                                          | QItemSelectionModel::Rows);
+                                     | QItemSelectionModel::Rows);
         }
 
         // restore expansion state but ensure that the root album is always
@@ -659,12 +717,12 @@ void AbstractAlbumTreeView::restoreState(const QModelIndex &index, QMap<int, Dig
         {
             //kDebug() << "Setting current index" << album->title() << "(" << album->id() << ")";
             selectionModel()->setCurrentIndex(index, QItemSelectionModel::SelectCurrent
-                                                   | QItemSelectionModel::Rows);
+                                              | QItemSelectionModel::Rows);
         }
     }
 }
 
-void AbstractAlbumTreeView::rowsInserted(const QModelIndex &parent, int start, int end)
+void AbstractAlbumTreeView::rowsInserted(const QModelIndex& parent, int start, int end)
 {
     QTreeView::rowsInserted(parent, start, end);
 
@@ -694,9 +752,12 @@ void AbstractAlbumTreeView::rowsAboutToBeRemoved(const QModelIndex& parent, int
         for (int i = start; i <= end; ++i)
         {
             const QModelIndex child = model()->index(i, 0, parent);
-            Album *album = albumModel()->albumForIndex(child);
+            Album* album = albumModel()->albumForIndex(child);
+
             if (album)
+            {
                 d->statesByAlbumId.remove(album->id());
+            }
         }
     }
 }
@@ -709,13 +770,14 @@ void AbstractAlbumTreeView::adaptColumnsToContent()
 void AbstractAlbumTreeView::scrollToSelectedAlbum()
 {
     QModelIndexList selected = selectedIndexes();
+
     if (!selected.isEmpty())
     {
         scrollTo(selected.first(), PositionAtCenter);
     }
 }
 
-void AbstractAlbumTreeView::expandEverything(const QModelIndex &index)
+void AbstractAlbumTreeView::expandEverything(const QModelIndex& index)
 {
 
     for (int row = 0; row < albumFilterModel()->rowCount(index); ++row)
@@ -727,27 +789,35 @@ void AbstractAlbumTreeView::expandEverything(const QModelIndex &index)
 
 }
 
-void AbstractAlbumTreeView::adaptColumnsOnDataChange(const QModelIndex &topLeft, const QModelIndex &bottomRight)
+void AbstractAlbumTreeView::adaptColumnsOnDataChange(const QModelIndex& topLeft, const QModelIndex& bottomRight)
 {
     Q_UNUSED(topLeft);
     Q_UNUSED(bottomRight);
+
     if (!d->resizeColumnsTimer->isActive())
+    {
         d->resizeColumnsTimer->start();
+    }
 }
 
-void AbstractAlbumTreeView::adaptColumnsOnRowChange(const QModelIndex &parent, int start, int end)
+void AbstractAlbumTreeView::adaptColumnsOnRowChange(const QModelIndex& parent, int start, int end)
 {
     Q_UNUSED(parent);
     Q_UNUSED(start);
     Q_UNUSED(end);
+
     if (!d->resizeColumnsTimer->isActive())
+    {
         d->resizeColumnsTimer->start();
+    }
 }
 
 void AbstractAlbumTreeView::adaptColumnsOnLayoutChange()
 {
     if (!d->resizeColumnsTimer->isActive())
+    {
         d->resizeColumnsTimer->start();
+    }
 }
 
 void AbstractAlbumTreeView::doSaveState()
@@ -756,22 +826,24 @@ void AbstractAlbumTreeView::doSaveState()
     KConfigGroup configGroup = getConfigGroup();
 
     QList<int> selection, expansion;
+
     for (int i = 0; i < model()->rowCount(); ++i)
     {
         const QModelIndex index = model()->index(i, 0);
         saveStateRecursive(index, selection, expansion);
     }
 
-    Album *selectedAlbum = albumFilterModel()->albumForIndex(selectionModel()->currentIndex());
+    Album* selectedAlbum = albumFilterModel()->albumForIndex(selectionModel()->currentIndex());
     QString currentIndex;
+
     if (selectedAlbum)
     {
         currentIndex = QString::number(selectedAlbum->id());
     }
 
-//    kDebug() << "selection: " << selection;
-//    kDebug() << "expansion: " << expansion;
-//    kDebug() << "currentIndex: " << currentIndex;
+    //    kDebug() << "selection: " << selection;
+    //    kDebug() << "expansion: " << expansion;
+    //    kDebug() << "currentIndex: " << currentIndex;
 
     configGroup.writeEntry(entryName(d->configSelectionEntry), selection);
     configGroup.writeEntry(entryName(d->configExpansionEntry), expansion);
@@ -781,18 +853,25 @@ void AbstractAlbumTreeView::doSaveState()
 
 }
 
-void AbstractAlbumTreeView::saveStateRecursive(const QModelIndex &index,
-                QList<int> &selection, QList<int> &expansion)
+void AbstractAlbumTreeView::saveStateRecursive(const QModelIndex& index,
+        QList<int> &selection, QList<int> &expansion)
 {
 
-    Album *album = albumFilterModel()->albumForIndex(index);
+    Album* album = albumFilterModel()->albumForIndex(index);
+
     if (album)
     {
         const int id = album->id();
+
         if (selectionModel()->isSelected(index))
+        {
             selection.append(id);
+        }
+
         if (isExpanded(index))
+        {
             expansion.append(id);
+        }
     }
 
     for (int i = 0; i < model()->rowCount(index); ++i)
@@ -808,7 +887,7 @@ void AbstractAlbumTreeView::setEnableContextMenu(bool enable)
     d->enableContextMenu = enable;
 }
 
-bool AbstractAlbumTreeView::showContextMenuAt(QContextMenuEvent *event, Album *albumForEvent)
+bool AbstractAlbumTreeView::showContextMenuAt(QContextMenuEvent* event, Album* albumForEvent)
 {
     Q_UNUSED(event);
     return albumForEvent;
@@ -824,7 +903,7 @@ QString AbstractAlbumTreeView::contextMenuTitle() const
     return i18n("Context menu");
 }
 
-void AbstractAlbumTreeView::contextMenuEvent(QContextMenuEvent *event)
+void AbstractAlbumTreeView::contextMenuEvent(QContextMenuEvent* event)
 {
 
     if (!d->enableContextMenu)
@@ -832,7 +911,7 @@ void AbstractAlbumTreeView::contextMenuEvent(QContextMenuEvent *event)
         return;
     }
 
-    Album *album = albumFilterModel()->albumForIndex(indexAt(event->pos()));
+    Album* album = albumFilterModel()->albumForIndex(indexAt(event->pos()));
 
     if (!showContextMenuAt(event, album))
     {
@@ -840,7 +919,7 @@ void AbstractAlbumTreeView::contextMenuEvent(QContextMenuEvent *event)
     }
 
     // switch to the selected album if need
-    if(d->selectOnContextMenu && album)
+    if (d->selectOnContextMenu && album)
     {
         slotSelectAlbum(album);
     }
@@ -863,13 +942,13 @@ void AbstractAlbumTreeView::setSelectOnContextMenu(bool select)
     d->selectOnContextMenu = select;
 }
 
-void AbstractAlbumTreeView::addCustomContextMenuActions(ContextMenuHelper &cmh, Album *album)
+void AbstractAlbumTreeView::addCustomContextMenuActions(ContextMenuHelper& cmh, Album* album)
 {
     Q_UNUSED(cmh);
     Q_UNUSED(album);
 }
 
-void AbstractAlbumTreeView::handleCustomContextMenuAction(QAction *action, AlbumPointer<Album> album)
+void AbstractAlbumTreeView::handleCustomContextMenuAction(QAction* action, AlbumPointer<Album> album)
 {
     Q_UNUSED(action);
     Q_UNUSED(album);
@@ -882,20 +961,23 @@ void AbstractAlbumTreeView::albumSettingsChanged()
 
 // --------------------------------------- //
 
-AbstractCountingAlbumTreeView::AbstractCountingAlbumTreeView(AbstractCountingAlbumModel *model,
-                                                             AlbumFilterModel *filterModel, QWidget *parent)
+AbstractCountingAlbumTreeView::AbstractCountingAlbumTreeView(AbstractCountingAlbumModel* model,
+        AlbumFilterModel* filterModel, QWidget* parent)
     : AbstractAlbumTreeView(model, filterModel, parent)
 {
     // install our own connections
     if (filterModel)
+    {
         setAlbumFilterModel(filterModel);
+    }
+
     setupConnections();
 }
 
-AbstractCountingAlbumTreeView::AbstractCountingAlbumTreeView(AbstractCountingAlbumModel *model, QWidget *parent)
+AbstractCountingAlbumTreeView::AbstractCountingAlbumTreeView(AbstractCountingAlbumModel* model, QWidget* parent)
     : AbstractAlbumTreeView(model, 0, parent)
 {
-    AlbumFilterModel *filterModel = new AlbumFilterModel(this);
+    AlbumFilterModel* filterModel = new AlbumFilterModel(this);
     setAlbumFilterModel(filterModel);
     setupConnections();
 }
@@ -903,19 +985,19 @@ AbstractCountingAlbumTreeView::AbstractCountingAlbumTreeView(AbstractCountingAlb
 
 void AbstractCountingAlbumTreeView::setupConnections()
 {
-    connect(this, SIGNAL(expanded(const QModelIndex &)),
-             this, SLOT(slotExpanded(const QModelIndex &)));
+    connect(this, SIGNAL(expanded(const QModelIndex&)),
+            this, SLOT(slotExpanded(const QModelIndex&)));
 
-    connect(this, SIGNAL(collapsed(const QModelIndex &)),
-             this, SLOT(slotCollapsed(const QModelIndex &)));
+    connect(this, SIGNAL(collapsed(const QModelIndex&)),
+            this, SLOT(slotCollapsed(const QModelIndex&)));
 
     connect(AlbumSettings::instance(), SIGNAL(setupChanged()),
-             this, SLOT(slotSetShowCount()));
+            this, SLOT(slotSetShowCount()));
 
     slotSetShowCount();
 }
 
-void AbstractCountingAlbumTreeView::setAlbumFilterModel(AlbumFilterModel *filterModel)
+void AbstractCountingAlbumTreeView::setAlbumFilterModel(AlbumFilterModel* filterModel)
 {
     AbstractAlbumTreeView::setAlbumFilterModel(filterModel);
 
@@ -926,15 +1008,22 @@ void AbstractCountingAlbumTreeView::setAlbumFilterModel(AlbumFilterModel *filter
 void AbstractCountingAlbumTreeView::updateShowCountState(const QModelIndex& index, bool recurse)
 {
     if (isExpanded(index))
+    {
         slotExpanded(index);
+    }
     else
+    {
         slotCollapsed(index);
+    }
 
     if (recurse)
     {
         int rows = m_albumFilterModel->rowCount(index);
+
         for (int i=0; i<rows; ++i)
+        {
             updateShowCountState(m_albumFilterModel->index(i, 0, index), true);
+        }
     }
 }
 
@@ -956,9 +1045,12 @@ void AbstractCountingAlbumTreeView::slotSetShowCount()
 void AbstractCountingAlbumTreeView::rowsInserted(const QModelIndex& parent, int start, int end)
 {
     AbstractAlbumTreeView::rowsInserted(parent, start, end);
+
     // initialize showCount state when items are added
     for (int i=start; i<=end; ++i)
+    {
         updateShowCountState(m_albumFilterModel->index(i, 0, parent), false);
+    }
 }
 
 // --------------------------------------- //
@@ -985,8 +1077,8 @@ const QString AbstractCheckableAlbumTreeViewPriv::configRestoreCheckedEntry("Res
 
 // --------------------------------------------------------
 
-AbstractCheckableAlbumTreeView::AbstractCheckableAlbumTreeView(AbstractCheckableAlbumModel *model,
-                                                               CheckableAlbumFilterModel *filterModel, QWidget *parent)
+AbstractCheckableAlbumTreeView::AbstractCheckableAlbumTreeView(AbstractCheckableAlbumModel* model,
+        CheckableAlbumFilterModel* filterModel, QWidget* parent)
     : AbstractCountingAlbumTreeView(model, filterModel, parent),
       d(new AbstractCheckableAlbumTreeViewPriv)
 {
@@ -994,14 +1086,14 @@ AbstractCheckableAlbumTreeView::AbstractCheckableAlbumTreeView(AbstractCheckable
     m_restoreCheckState  = false;
 }
 
-AbstractCheckableAlbumTreeView::AbstractCheckableAlbumTreeView(AbstractCheckableAlbumModel *model, QWidget *parent)
+AbstractCheckableAlbumTreeView::AbstractCheckableAlbumTreeView(AbstractCheckableAlbumModel* model, QWidget* parent)
     : AbstractCountingAlbumTreeView(model, 0, parent),
       d(new AbstractCheckableAlbumTreeViewPriv)
 {
     m_checkOnMiddleClick = true;
     m_restoreCheckState  = false;
 
-    CheckableAlbumFilterModel *filterModel = new CheckableAlbumFilterModel(this);
+    CheckableAlbumFilterModel* filterModel = new CheckableAlbumFilterModel(this);
     setAlbumFilterModel(filterModel);
 }
 
@@ -1010,12 +1102,12 @@ AbstractCheckableAlbumTreeView::~AbstractCheckableAlbumTreeView()
     delete d;
 }
 
-AbstractCheckableAlbumModel *AbstractCheckableAlbumTreeView::checkableModel() const
+AbstractCheckableAlbumModel* AbstractCheckableAlbumTreeView::checkableModel() const
 {
     return dynamic_cast<AbstractCheckableAlbumModel*>(m_albumModel);
 }
 
-CheckableAlbumFilterModel *AbstractCheckableAlbumTreeView::checkableAlbumFilterModel() const
+CheckableAlbumFilterModel* AbstractCheckableAlbumTreeView::checkableAlbumFilterModel() const
 {
     return dynamic_cast<CheckableAlbumFilterModel*> (m_albumFilterModel);
 }
@@ -1025,9 +1117,10 @@ void AbstractCheckableAlbumTreeView::setCheckOnMiddleClick(bool doThat)
     m_checkOnMiddleClick = doThat;
 }
 
-void AbstractCheckableAlbumTreeView::middleButtonPressed(Album *a)
+void AbstractCheckableAlbumTreeView::middleButtonPressed(Album* a)
 {
     AbstractCheckableAlbumModel* model = static_cast<AbstractCheckableAlbumModel*>(m_albumModel);
+
     if (!model)
     {
         return;
@@ -1081,13 +1174,14 @@ void AbstractCheckableAlbumTreeView::doLoadState()
     }
 
     QStringList checkedAlbums = group.readEntry(entryName(
-                    d->configCheckedAlbumsEntry), QStringList());
+                                    d->configCheckedAlbumsEntry), QStringList());
 
     d->checkedAlbumIds.clear();
     foreach(const QString& albumId, checkedAlbums)
     {
         bool ok;
         int id = albumId.toInt(&ok);
+
         if (ok)
         {
             d->checkedAlbumIds << id;
@@ -1095,13 +1189,14 @@ void AbstractCheckableAlbumTreeView::doLoadState()
     }
 
     QStringList partiallyCheckedAlbums = group.readEntry(entryName(
-                    d->configPartiallyCheckedAlbumsEntry), QStringList());
+            d->configPartiallyCheckedAlbumsEntry), QStringList());
 
     d->partiallyCheckedAlbumIds.clear();
     foreach(const QString& albumId, partiallyCheckedAlbums)
     {
         bool ok;
         int id = albumId.toInt(&ok);
+
         if (ok)
         {
             d->partiallyCheckedAlbumIds << id;
@@ -1115,6 +1210,7 @@ void AbstractCheckableAlbumTreeView::doLoadState()
 void AbstractCheckableAlbumTreeView::rowsInserted(const QModelIndex& parent, int start, int end)
 {
     AbstractCountingAlbumTreeView::rowsInserted(parent, start, end);
+
     if (!d->checkedAlbumIds.isEmpty())
     {
         for (int i = start; i <= end; ++i)
@@ -1125,7 +1221,7 @@ void AbstractCheckableAlbumTreeView::rowsInserted(const QModelIndex& parent, int
     }
 }
 
-void AbstractCheckableAlbumTreeView::restoreCheckStateForHierarchy(const QModelIndex &index)
+void AbstractCheckableAlbumTreeView::restoreCheckStateForHierarchy(const QModelIndex& index)
 {
     // recurse children
     for (int i = 0; i < checkableModel()->rowCount(index); ++i)
@@ -1136,9 +1232,10 @@ void AbstractCheckableAlbumTreeView::restoreCheckStateForHierarchy(const QModelI
     }
 }
 
-void AbstractCheckableAlbumTreeView::restoreCheckState(const QModelIndex &index)
+void AbstractCheckableAlbumTreeView::restoreCheckState(const QModelIndex& index)
 {
-    Album *album = checkableModel()->albumForIndex(index);
+    Album* album = checkableModel()->albumForIndex(index);
+
     if (!album)
     {
         return;
@@ -1149,6 +1246,7 @@ void AbstractCheckableAlbumTreeView::restoreCheckState(const QModelIndex &index)
         checkableModel()->setCheckState(album, Qt::Checked);
         d->checkedAlbumIds.removeOne(album->id());
     }
+
     if (d->partiallyCheckedAlbumIds.contains(album->id()))
     {
         checkableModel()->setCheckState(album, Qt::PartiallyChecked);
@@ -1196,10 +1294,10 @@ void AbstractCheckableAlbumTreeView::doSaveState()
 
 // --------------------------------------- //
 
-AlbumTreeView::AlbumTreeView(AlbumModel *model, QWidget *parent)
+AlbumTreeView::AlbumTreeView(AlbumModel* model, QWidget* parent)
     : AbstractCheckableAlbumTreeView(model, parent)
 {
-    AlbumDragDropHandler *handler = new AlbumDragDropHandler(albumModel());
+    AlbumDragDropHandler* handler = new AlbumDragDropHandler(albumModel());
     albumModel()->setDragDropHandler(handler);
     connect(handler, SIGNAL(dioResult(KJob*)),
             this, SLOT(slotDIOResult(KJob*)));
@@ -1221,7 +1319,7 @@ AlbumTreeView::~AlbumTreeView()
 {
 }
 
-AlbumModel *AlbumTreeView::albumModel() const
+AlbumModel* AlbumTreeView::albumModel() const
 {
     return dynamic_cast<AlbumModel*>(m_albumModel);
 }
@@ -1231,14 +1329,15 @@ PAlbum* AlbumTreeView::currentAlbum() const
     return dynamic_cast<PAlbum*> (m_albumFilterModel->albumForIndex(currentIndex()));
 }
 
-PAlbum *AlbumTreeView::albumForIndex(const QModelIndex &index) const
+PAlbum* AlbumTreeView::albumForIndex(const QModelIndex& index) const
 {
     return dynamic_cast<PAlbum*> (m_albumFilterModel->albumForIndex(index));
 }
 
-void AlbumTreeView::slotDIOResult(KJob *kjob)
+void AlbumTreeView::slotDIOResult(KJob* kjob)
 {
-    KIO::Job *job = static_cast<KIO::Job*>(kjob);
+    KIO::Job* job = static_cast<KIO::Job*>(kjob);
+
     if (job->error())
     {
         job->ui()->setWindow(this);
@@ -1248,7 +1347,7 @@ void AlbumTreeView::slotDIOResult(KJob *kjob)
 
 // --------------------------------------- //
 
-TagTreeView::TagTreeView(TagModel *model, QWidget *parent)
+TagTreeView::TagTreeView(TagModel* model, QWidget* parent)
     : AbstractCheckableAlbumTreeView(model, parent)
 {
     m_modificationHelper = new TagModificationHelper(this, this);
@@ -1259,12 +1358,15 @@ TagTreeView::TagTreeView(TagModel *model, QWidget *parent)
             MetadataManager::instance(), SLOT(assignTags(const QList<int>&, const QList<int>&)));
 
     connect(AlbumManager::instance(), SIGNAL(signalTAlbumsDirty(const QMap<int, int>&)),
-             m_albumModel, SLOT(setCountMap(const QMap<int, int>&)));
+            m_albumModel, SLOT(setCountMap(const QMap<int, int>&)));
     albumModel()->setCountMap(AlbumManager::instance()->getTAlbumsCount());
 
     expand(m_albumFilterModel->rootAlbumIndex());
+
     if (m_albumModel->rootAlbumBehavior() == AbstractAlbumModel::IncludeRootAlbum)
+    {
         setRootIsDecorated(false);
+    }
 
     setDragEnabled(true);
     setAcceptDrops(true);
@@ -1272,7 +1374,7 @@ TagTreeView::TagTreeView(TagModel *model, QWidget *parent)
     setAutoExpandDelay(300);
 }
 
-TagModel *TagTreeView::albumModel() const
+TagModel* TagTreeView::albumModel() const
 {
     return static_cast<TagModel*>(m_albumModel);
 }
@@ -1282,25 +1384,25 @@ TAlbum* TagTreeView::currentAlbum() const
     return dynamic_cast<TAlbum*> (m_albumFilterModel->albumForIndex(currentIndex()));
 }
 
-TAlbum *TagTreeView::albumForIndex(const QModelIndex &index) const
+TAlbum* TagTreeView::albumForIndex(const QModelIndex& index) const
 {
     return dynamic_cast<TAlbum*> (m_albumFilterModel->albumForIndex(index));
 }
 
-TagModificationHelper *TagTreeView::tagModificationHelper() const
+TagModificationHelper* TagTreeView::tagModificationHelper() const
 {
     return m_modificationHelper;
 }
 
 // --------------------------------------- //
 
-SearchTreeView::SearchTreeView(QWidget *parent, SearchModel *searchModel)
+SearchTreeView::SearchTreeView(QWidget* parent, SearchModel* searchModel)
     : AbstractCheckableAlbumTreeView(searchModel, parent)
 {
     m_filteredModel = new SearchFilterModel(this);
     m_filteredModel->setSourceSearchModel(searchModel);
 
-    AlbumFilterModel *albumFilterModel = new AlbumFilterModel(this);
+    AlbumFilterModel* albumFilterModel = new AlbumFilterModel(this);
     setAlbumFilterModel(albumFilterModel);
     albumFilterModel->setSourceAlbumModel(m_filteredModel);
 
@@ -1308,12 +1410,12 @@ SearchTreeView::SearchTreeView(QWidget *parent, SearchModel *searchModel)
     setRootIsDecorated(false);
 }
 
-SearchModel *SearchTreeView::albumModel() const
+SearchModel* SearchTreeView::albumModel() const
 {
     return static_cast<SearchModel*>(m_albumModel);
 }
 
-SearchFilterModel *SearchTreeView::filteredModel() const
+SearchFilterModel* SearchTreeView::filteredModel() const
 {
     return m_filteredModel;
 }
@@ -1323,24 +1425,24 @@ SAlbum* SearchTreeView::currentAlbum() const
     return dynamic_cast<SAlbum*> (m_albumFilterModel->albumForIndex(currentIndex()));
 }
 
-void SearchTreeView::slotSelectSAlbum(SAlbum *salbum)
+void SearchTreeView::slotSelectSAlbum(SAlbum* salbum)
 {
     slotSelectAlbum(salbum, true);
 }
 
 // --------------------------------------- //
 
-DateAlbumTreeView::DateAlbumTreeView(QWidget *parent, DateAlbumModel *dateAlbumModel)
+DateAlbumTreeView::DateAlbumTreeView(QWidget* parent, DateAlbumModel* dateAlbumModel)
     : AbstractCountingAlbumTreeView(dateAlbumModel, parent)
 {
     // this view should always show the inclusive counts
-    disconnect(this, SIGNAL(expanded(const QModelIndex &)),
-               this, SLOT(slotExpanded(const QModelIndex &)));
-    disconnect(this, SIGNAL(collapsed(const QModelIndex &)),
-               this, SLOT(slotCollapsed(const QModelIndex &)));
+    disconnect(this, SIGNAL(expanded(const QModelIndex&)),
+               this, SLOT(slotExpanded(const QModelIndex&)));
+    disconnect(this, SIGNAL(collapsed(const QModelIndex&)),
+               this, SLOT(slotCollapsed(const QModelIndex&)));
 }
 
-DateAlbumModel *DateAlbumTreeView::albumModel() const
+DateAlbumModel* DateAlbumTreeView::albumModel() const
 {
     return static_cast<DateAlbumModel*>(m_albumModel);
 }
@@ -1350,7 +1452,7 @@ DAlbum* DateAlbumTreeView::currentAlbum() const
     return dynamic_cast<DAlbum*> (m_albumFilterModel->albumForIndex(currentIndex()));
 }
 
-DAlbum *DateAlbumTreeView::albumForIndex(const QModelIndex &index) const
+DAlbum* DateAlbumTreeView::albumForIndex(const QModelIndex& index) const
 {
     return dynamic_cast<DAlbum*> (m_albumFilterModel->albumForIndex(index));
 }
