@@ -47,7 +47,10 @@
 
 class KAction;
 
-namespace Solid { class Device; }
+namespace Solid
+{
+class Device;
+}
 
 namespace Digikam
 {
@@ -92,8 +95,8 @@ public:
     void startInternalDatabase();
     void stopInternalDatabase();
 
-    DigikamView *view() const;
-    AlbumIconViewFilter *iconViewFilter() const;
+    DigikamView* view() const;
+    AlbumIconViewFilter* iconViewFilter() const;
 
 Q_SIGNALS:
 
@@ -115,7 +118,7 @@ Q_SIGNALS:
 protected:
 
     bool queryClose();
-    void moveEvent(QMoveEvent *e);
+    void moveEvent(QMoveEvent* e);
 
 private:
 
@@ -129,6 +132,7 @@ private:
     void loadPlugins();
     void loadCameras();
     void populateThemes();
+    void preloadWindows();
     void fillSolidMenus();
     bool checkSolidCamera(const Solid::Device& cameraDevice);
     QString labelForSolidCamera(const Solid::Device& cameraDevice);
@@ -168,9 +172,9 @@ private Q_SLOTS:
 
     void slotKipiPluginPlug();
 
-    void slotOpenSolidCamera(QAction *);
-    void slotOpenManualCamera(QAction *);
-    void slotOpenSolidUsmDevice(QAction *);
+    void slotOpenSolidCamera(QAction*);
+    void slotOpenManualCamera(QAction*);
+    void slotOpenSolidUsmDevice(QAction*);
     void slotOpenSolidDevice(const QString& udi);
     void slotOpenCameraUiFromPath(const QString& path);
     void slotSolidSetupDone(Solid::ErrorType errorType, QVariant errorData, const QString& udi);
@@ -215,7 +219,7 @@ private:
 
     DigikamAppPriv* const d;
 
-    static DigikamApp *m_instance;
+    static DigikamApp* m_instance;
 };
 
 }  // namespace Digikam
