@@ -93,14 +93,14 @@ public:
 
     QPixmap       ratingPixmap;
 
-    ThumbBarItem *ratingItem;
+    ThumbBarItem* ratingItem;
 
-    RatingWidget *ratingWidget;
+    RatingWidget* ratingWidget;
 };
 
 ImagePreviewBar::ImagePreviewBar(QWidget* parent, int orientation, bool exifRotate)
-               : ThumbBarView(parent, orientation, exifRotate), 
-                 d(new ImagePreviewBarPriv)
+    : ThumbBarView(parent, orientation, exifRotate),
+      d(new ImagePreviewBarPriv)
 {
     setMouseTracking(true);
     readToolTipSettings();
@@ -125,13 +125,17 @@ ImagePreviewBar::ImagePreviewBar(QWidget* parent, int orientation, bool exifRota
     d->ratingWidget->hide();
 
     if (orientation == Qt::Vertical)
+    {
         setMinimumWidth(d->ratingPixmap.width()*5 + 6 + 2*getMargin() + 2*getRadius());
+    }
     else
+    {
         setMinimumHeight(d->ratingPixmap.width()*5 + 6 + 2*getMargin() + 2*getRadius());
+    }
 
     // ----------------------------------------------------------------
 
-    ImageAttributesWatch *watch = ImageAttributesWatch::instance();
+    ImageAttributesWatch* watch = ImageAttributesWatch::instance();
 
     connect(watch, SIGNAL(signalImageRatingChanged(qlonglong)),
             this, SLOT(slotImageRatingChanged(qlonglong)));
@@ -150,7 +154,8 @@ ImagePreviewBar::~ImagePreviewBar()
 
 void ImagePreviewBar::clear(bool updateView)
 {
-    ThumbBarItem *item = d->ratingItem;
+    ThumbBarItem* item = d->ratingItem;
+
     if (item)
     {
         unsetCursor();
@@ -164,7 +169,10 @@ void ImagePreviewBar::clear(bool updateView)
 
 void ImagePreviewBar::takeItem(ThumbBarItem* item)
 {
-    if (!item) return;
+    if (!item)
+    {
+        return;
+    }
 
     if (d->ratingItem == item)
     {
@@ -179,7 +187,10 @@ void ImagePreviewBar::takeItem(ThumbBarItem* item)
 
 void ImagePreviewBar::removeItem(ThumbBarItem* item)
 {
-    if (!item) return;
+    if (!item)
+    {
+        return;
+    }
 
     if (d->ratingItem == item)
     {
@@ -194,7 +205,8 @@ void ImagePreviewBar::removeItem(ThumbBarItem* item)
 
 void ImagePreviewBar::rearrangeItems()
 {
-    ThumbBarItem *item = d->ratingItem;
+    ThumbBarItem* item = d->ratingItem;
+
     if (item)
     {
         unsetCursor();
@@ -208,9 +220,13 @@ void ImagePreviewBar::rearrangeItems()
 
 void ImagePreviewBar::ensureItemVisible(ThumbBarItem* item)
 {
-    if (!item) return;
+    if (!item)
+    {
+        return;
+    }
+
+    ThumbBarItem* ritem = d->ratingItem;
 
-    ThumbBarItem *ritem = d->ratingItem;
     if (ritem)
     {
         unsetCursor();
@@ -224,7 +240,8 @@ void ImagePreviewBar::ensureItemVisible(ThumbBarItem* item)
 
 void ImagePreviewBar::leaveEvent(QEvent* e)
 {
-    ThumbBarItem *item = d->ratingItem;
+    ThumbBarItem* item = d->ratingItem;
+
     if (item)
     {
         unsetCursor();
@@ -238,7 +255,8 @@ void ImagePreviewBar::leaveEvent(QEvent* e)
 
 void ImagePreviewBar::focusOutEvent(QFocusEvent* e)
 {
-    ThumbBarItem *item = d->ratingItem;
+    ThumbBarItem* item = d->ratingItem;
+
     if (item)
     {
         unsetCursor();
@@ -252,7 +270,8 @@ void ImagePreviewBar::focusOutEvent(QFocusEvent* e)
 
 void ImagePreviewBar::contentsWheelEvent(QWheelEvent* e)
 {
-    ThumbBarItem *item = d->ratingItem;
+    ThumbBarItem* item = d->ratingItem;
+
     if (item)
     {
         unsetCursor();
@@ -276,15 +295,20 @@ QPixmap ImagePreviewBar::ratingPixmap() const
 
 void ImagePreviewBar::setSelectedItem(ImagePreviewBarItem* ltItem)
 {
-    ThumbBarItem *item = dynamic_cast<ThumbBarItem*>(ltItem);
-    if (item) ThumbBarView::setSelected(item);
+    ThumbBarItem* item = dynamic_cast<ThumbBarItem*>(ltItem);
+
+    if (item)
+    {
+        ThumbBarView::setSelected(item);
+    }
 }
 
 void ImagePreviewBar::slotImageRatingChanged(qlonglong imageId)
 {
-    for (ThumbBarItem *item = firstItem(); item; item = item->next())
+    for (ThumbBarItem* item = firstItem(); item; item = item->next())
     {
-        ImagePreviewBarItem *ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+        ImagePreviewBarItem* ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+
         if (ltItem->info().id() == imageId)
         {
             triggerUpdate();
@@ -295,11 +319,16 @@ void ImagePreviewBar::slotImageRatingChanged(qlonglong imageId)
 
 void ImagePreviewBar::slotEditRatingFromItem(int rating)
 {
-    if (!d->ratingItem) return;
-    ImagePreviewBarItem *ltItem = dynamic_cast<ImagePreviewBarItem*>(d->ratingItem);
+    if (!d->ratingItem)
+    {
+        return;
+    }
+
+    ImagePreviewBarItem* ltItem = dynamic_cast<ImagePreviewBarItem*>(d->ratingItem);
 
     rating = qMin(5, qMax(0, rating));
     ImageInfo info = ltItem->info();
+
     if (!info.isNull())
     {
         MetadataHub hub;
@@ -314,7 +343,7 @@ ImageInfo ImagePreviewBar::currentItemImageInfo() const
 {
     if (currentItem())
     {
-        ImagePreviewBarItem *item = dynamic_cast<ImagePreviewBarItem*>(currentItem());
+        ImagePreviewBarItem* item = dynamic_cast<ImagePreviewBarItem*>(currentItem());
         return item->info();
     }
 
@@ -325,9 +354,10 @@ ImageInfoList ImagePreviewBar::itemsImageInfoList()
 {
     ImageInfoList list;
 
-    for (ThumbBarItem *item = firstItem(); item; item = item->next())
+    for (ThumbBarItem* item = firstItem(); item; item = item->next())
     {
-        ImagePreviewBarItem *ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+        ImagePreviewBarItem* ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+
         if (ltItem)
         {
             list << ltItem->info();
@@ -341,25 +371,30 @@ ImagePreviewBarItem* ImagePreviewBar::findItemByInfo(const ImageInfo& info) cons
 {
     if (!info.isNull())
     {
-        for (ThumbBarItem *item = firstItem(); item; item = item->next())
+        for (ThumbBarItem* item = firstItem(); item; item = item->next())
         {
-            ImagePreviewBarItem *ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+            ImagePreviewBarItem* ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+
             if (ltItem)
             {
                 if (ltItem->info() == info)
+                {
                     return ltItem;
+                }
             }
         }
     }
+
     return 0;
 }
 
 ImagePreviewBarItem* ImagePreviewBar::findItemByPos(const QPoint& pos) const
 {
-    ThumbBarItem *item = findItem(pos);
+    ThumbBarItem* item = findItem(pos);
+
     if (item)
     {
-        ImagePreviewBarItem *ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
+        ImagePreviewBarItem* ltItem = dynamic_cast<ImagePreviewBarItem*>(item);
         return ltItem;
     }
 
@@ -371,7 +406,11 @@ void ImagePreviewBar::applySettings()
     readToolTipSettings();
 
     AlbumSettings* albumSettings = AlbumSettings::instance();
-    if (!albumSettings) return;
+
+    if (!albumSettings)
+    {
+        return;
+    }
 
     setExifRotate(albumSettings->getExifRotate());
 }
@@ -379,7 +418,11 @@ void ImagePreviewBar::applySettings()
 void ImagePreviewBar::readToolTipSettings()
 {
     AlbumSettings* albumSettings = AlbumSettings::instance();
-    if (!albumSettings) return;
+
+    if (!albumSettings)
+    {
+        return;
+    }
 
     Digikam::ThumbBarToolTipSettings settings;
     settings.showToolTips   = albumSettings->getShowToolTips();
@@ -400,14 +443,17 @@ void ImagePreviewBar::readToolTipSettings()
 
 void ImagePreviewBar::startDrag()
 {
-    if (!currentItem()) return;
+    if (!currentItem())
+    {
+        return;
+    }
 
     KUrl::List urls;
     KUrl::List kioURLs;
     QList<int> albumIDs;
     QList<int> imageIDs;
 
-    ImagePreviewBarItem *item = dynamic_cast<ImagePreviewBarItem*>(currentItem());
+    ImagePreviewBarItem* item = dynamic_cast<ImagePreviewBarItem*>(currentItem());
 
     urls.append(item->info().fileUrl());
     kioURLs.append(item->info().databaseUrl());
@@ -415,6 +461,7 @@ void ImagePreviewBar::startDrag()
     albumIDs.append(item->info().albumId());
 
     QPixmap icon;
+
     if (pixmapForItem(item, icon))
     {
         icon = icon.scaled(48, 48, Qt::KeepAspectRatio);
@@ -423,6 +470,7 @@ void ImagePreviewBar::startDrag()
     {
         icon = DesktopIcon("image-jp2", 48);
     }
+
     int w = icon.width();
     int h = icon.height();
 
@@ -434,7 +482,7 @@ void ImagePreviewBar::startDrag()
     p.drawPixmap(2, 2, icon);
     p.end();
 
-    QDrag *drag = new QDrag(this);
+    QDrag* drag = new QDrag(this);
     drag->setMimeData(new DItemDrag(urls, kioURLs, albumIDs, imageIDs));
     drag->setPixmap(pix);
     drag->exec();
@@ -442,11 +490,15 @@ void ImagePreviewBar::startDrag()
 
 void ImagePreviewBar::contentsMouseMoveEvent(QMouseEvent* e)
 {
-    if (!e) return;
+    if (!e)
+    {
+        return;
+    }
 
     if (e->buttons() == Qt::NoButton)
     {
-        ImagePreviewBarItem *item = dynamic_cast<ImagePreviewBarItem*>(findItem(e->pos()));
+        ImagePreviewBarItem* item = dynamic_cast<ImagePreviewBarItem*>(findItem(e->pos()));
+
         if (item)
         {
             QRect rect = clickToRateRect(item);
@@ -483,14 +535,14 @@ void ImagePreviewBar::contentsMouseMoveEvent(QMouseEvent* e)
     ThumbBarView::contentsMouseMoveEvent(e);
 }
 
-void ImagePreviewBar::drawItem(ThumbBarItem *item, QPainter &p, QPixmap &tile)
+void ImagePreviewBar::drawItem(ThumbBarItem* item, QPainter& p, QPixmap& tile)
 {
 
     Q_UNUSED(tile);
 
     if (item != d->ratingItem)
     {
-        ImagePreviewBarItem *rItem = dynamic_cast<ImagePreviewBarItem*>(item);
+        ImagePreviewBarItem* rItem = dynamic_cast<ImagePreviewBarItem*>(item);
         int rating                 = rItem->info().rating();
         QRect r                    = clickToRateRect(rItem);
 
@@ -513,7 +565,7 @@ void ImagePreviewBar::drawItem(ThumbBarItem *item, QPainter &p, QPixmap &tile)
 
 }
 
-void ImagePreviewBar::drawEmptyMessage(QPixmap &pixmap)
+void ImagePreviewBar::drawEmptyMessage(QPixmap& pixmap)
 {
     Q_UNUSED(pixmap)
 }
@@ -556,16 +608,20 @@ void ImagePreviewBar::viewportPaintEvent(QPaintEvent* e)
 
         bgPix.fill(te->baseColor());
 
-        for (ThumbBarItem *item = firstItem(); item; item = item->next())
+        for (ThumbBarItem* item = firstItem(); item; item = item->next())
         {
             if (getOrientation() == Qt::Vertical)
             {
                 if (y1 <= item->position() && item->position() <= y2)
                 {
                     if (item == currentItem())
+                    {
                         tile = te->thumbSelPixmap(tile.width(), tile.height());
+                    }
                     else
+                    {
                         tile = te->thumbRegPixmap(tile.width(), tile.height());
+                    }
 
                     QPainter p(&tile);
 
@@ -588,6 +644,7 @@ void ImagePreviewBar::viewportPaintEvent(QPaintEvent* e)
                     }
 
                     QPixmap pix;
+
                     if (pixmapForItem(item, pix))
                     {
                         int x = (tile.width()  - pix.width())/2;
@@ -595,7 +652,7 @@ void ImagePreviewBar::viewportPaintEvent(QPaintEvent* e)
 
                         p.drawPixmap(x, y, pix);
                         p.drawPixmap(x-3, y-3, generateFuzzyRect(QSize(pix.width()+6, pix.height()+6),
-                                                                 QColor(0, 0, 0, 128), 3));
+                                     QColor(0, 0, 0, 128), 3));
                         item->setTooltipRect(QRect(x, y+item->position(), pix.width(), pix.height()));
 
                         drawItem(item, p, tile);
@@ -613,9 +670,13 @@ void ImagePreviewBar::viewportPaintEvent(QPaintEvent* e)
                 if (x1 <= item->position() && item->position() <= x2)
                 {
                     if (item == currentItem())
+                    {
                         tile = te->thumbSelPixmap(tile.width(), tile.height());
+                    }
                     else
+                    {
                         tile = te->thumbRegPixmap(tile.width(), tile.height());
+                    }
 
                     QPainter p(&tile);
 
@@ -638,13 +699,14 @@ void ImagePreviewBar::viewportPaintEvent(QPaintEvent* e)
                     }
 
                     QPixmap pix;
+
                     if (pixmapForItem(item, pix))
                     {
                         int x = (tile.width() - pix.width())/2;
                         int y = (tile.height()- pix.height())/2;
                         p.drawPixmap(x, y, pix);
                         p.drawPixmap(x-3, y-3, generateFuzzyRect(QSize(pix.width()+6, pix.height()+6),
-                                                                 QColor(0, 0, 0, 128), 3));
+                                     QColor(0, 0, 0, 128), 3));
                         item->setTooltipRect(QRect(x+item->position(), y, pix.width(), pix.height()));
 
                         drawItem(item, p, tile);
@@ -662,9 +724,13 @@ void ImagePreviewBar::viewportPaintEvent(QPaintEvent* e)
         QPainter p3(viewport());
 
         if (getOrientation() == Qt::Vertical)
+        {
             p3.drawPixmap(0, er.y(), bgPix);
+        }
         else
+        {
             p3.drawPixmap(er.x(), 0, bgPix);
+        }
 
         p3.end();
     }
@@ -694,17 +760,18 @@ void ImagePreviewBar::slotThemeChanged()
     slotUpdate();
 }
 
-// NOTE: see B.K.O #181184 : we need to catch mouse leave event from rating 
+// NOTE: see B.K.O #181184 : we need to catch mouse leave event from rating
 //       box when user move cursor over scrollbar.
 
-bool ImagePreviewBar::eventFilter(QObject *obj, QEvent *ev)
+bool ImagePreviewBar::eventFilter(QObject* obj, QEvent* ev)
 {
     if ( obj == d->ratingWidget )
     {
         if ( ev->type() == QEvent::Leave)
         {
             // Cave: ratingWidget->hide can recurse here again! See bug 184473
-            ThumbBarItem *item = d->ratingItem;
+            ThumbBarItem* item = d->ratingItem;
+
             if (item)
             {
                 unsetCursor();
@@ -731,8 +798,8 @@ QRect ImagePreviewBar::clickToRateRect(ImagePreviewBarItem* item)
 
 // -------------------------------------------------------------------------
 
-ImagePreviewBarItem::ImagePreviewBarItem(ImagePreviewBar *view, const ImageInfo& info)
-                   : ThumbBarItem(view, info.fileUrl())
+ImagePreviewBarItem::ImagePreviewBarItem(ImagePreviewBar* view, const ImageInfo& info)
+    : ThumbBarItem(view, info.fileUrl())
 {
     m_info = info;
 }
@@ -749,7 +816,7 @@ ImageInfo ImagePreviewBarItem::info()
 // -------------------------------------------------------------------------
 
 ImagePreviewBarToolTip::ImagePreviewBarToolTip(ThumbBarView* parent)
-                      : ThumbBarToolTip(parent)
+    : ThumbBarToolTip(parent)
 {
 }
 
@@ -759,8 +826,12 @@ ImagePreviewBarToolTip::~ImagePreviewBarToolTip()
 
 QString ImagePreviewBarToolTip::tipContents()
 {
-    if (!item()) return QString();
-    ImageInfo info = dynamic_cast<ImagePreviewBarItem *>(item())->info();
+    if (!item())
+    {
+        return QString();
+    }
+
+    ImageInfo info = dynamic_cast<ImagePreviewBarItem*>(item())->info();
     return ToolTipFiller::imageInfoTipContents(info);
 }
 
