@@ -26,9 +26,9 @@
 
 // Qt includes
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
+#include <QLabel>
+#include <QLayout>
+#include <QCheckBox>
 
 // KDE includes
 
@@ -43,7 +43,7 @@
 namespace Digikam
 {
 
-class TagFilterViewPriv
+class TagFilterView::TagFilterViewPriv
 {
 public:
 
@@ -59,23 +59,21 @@ public:
     {
     }
 
-    QAction*        onRestoreTagFiltersAction;
-    QAction*        offRestoreTagFiltersAction;
-    QAction*        ignoreTagAction;
-    QAction*        includeTagAction;
-    QAction*        excludeTagAction;
+    QAction*       onRestoreTagFiltersAction;
+    QAction*       offRestoreTagFiltersAction;
+    QAction*       ignoreTagAction;
+    QAction*       includeTagAction;
+    QAction*       excludeTagAction;
 
-    KSelectAction*  restoreTagFiltersAction;
-    KSelectAction*  tagFilterModeAction;
+    KSelectAction* restoreTagFiltersAction;
+    KSelectAction* tagFilterModeAction;
 
-    TagModel*       tagFilterModel;
+    TagModel*      tagFilterModel;
 };
 
-TagFilterView::TagFilterView(QWidget *parent, TagModel *tagFilterModel) :
-    TagCheckView(parent, tagFilterModel),
-    d(new TagFilterViewPriv)
+TagFilterView::TagFilterView(QWidget* parent, TagModel* tagFilterModel)
+    : TagCheckView(parent, tagFilterModel), d(new TagFilterViewPriv)
 {
-
     d->tagFilterModel             = tagFilterModel;
 
     d->restoreTagFiltersAction    = new KSelectAction(i18n("Restore Tag Filters"), this);
@@ -93,7 +91,7 @@ TagFilterView::~TagFilterView()
     delete d;
 }
 
-void TagFilterView::addCustomContextMenuActions(ContextMenuHelper &cmh, Album *album)
+void TagFilterView::addCustomContextMenuActions(ContextMenuHelper& cmh, Album* album)
 {
     TagCheckView::addCustomContextMenuActions(cmh, album);
 
@@ -101,6 +99,7 @@ void TagFilterView::addCustomContextMenuActions(ContextMenuHelper &cmh, Album *a
     cmh.addAction(d->restoreTagFiltersAction);
 
     Qt::CheckState state = d->tagFilterModel->checkState(album);
+
     switch (state)
     {
         case Qt::Unchecked:
@@ -113,14 +112,14 @@ void TagFilterView::addCustomContextMenuActions(ContextMenuHelper &cmh, Album *a
             d->tagFilterModeAction->setCurrentAction(d->includeTagAction);
             break;
     }
+
     cmh.addAction(d->tagFilterModeAction);
 
     d->onRestoreTagFiltersAction->setChecked(isRestoreCheckState());
     d->offRestoreTagFiltersAction->setChecked(!isRestoreCheckState());
-
 }
 
-void TagFilterView::handleCustomContextMenuAction(QAction *action, AlbumPointer<Album> album)
+void TagFilterView::handleCustomContextMenuAction(QAction* action, AlbumPointer<Album> album)
 {
     TagCheckView::handleCustomContextMenuAction(action, album);
 
@@ -149,12 +148,11 @@ void TagFilterView::handleCustomContextMenuAction(QAction *action, AlbumPointer<
     {
         albumModel()->setCheckState(album, Qt::PartiallyChecked);
     }
-
 }
 
-// -----------------------------------------------------------------------------
+// --------------------------------------------------------------------------------------------------------
 
-class TagFilterSideBarWidgetPriv
+class TagFilterSideBarWidget::TagFilterSideBarWidgetPriv
 {
 public:
 
@@ -179,16 +177,15 @@ public:
     KComboBox*           matchingConditionComboBox;
 
 };
-const QString TagFilterSideBarWidgetPriv::configLastShowUntaggedEntry("Show Untagged");
-const QString TagFilterSideBarWidgetPriv::configMatchingConditionEntry("Matching Condition");
 
-// --------------------------------------------------------
+const QString TagFilterSideBarWidget::TagFilterSideBarWidgetPriv::configLastShowUntaggedEntry("Show Untagged");
+const QString TagFilterSideBarWidget::TagFilterSideBarWidgetPriv::configMatchingConditionEntry("Matching Condition");
 
-TagFilterSideBarWidget::TagFilterSideBarWidget(QWidget *parent,
-                TagModel *tagFilterModel) :
-    QWidget(parent), StateSavingObject(this), d(new TagFilterSideBarWidgetPriv)
+// ---------------------------------------------------------------------------------------------------
+
+TagFilterSideBarWidget::TagFilterSideBarWidget(QWidget* parent, TagModel* tagFilterModel)
+    : QWidget(parent), StateSavingObject(this), d(new TagFilterSideBarWidgetPriv)
 {
-
     setObjectName("TagFilter Sidebar");
 
     d->tagFilterModel = tagFilterModel;
@@ -203,17 +200,17 @@ TagFilterSideBarWidget::TagFilterSideBarWidget(QWidget *parent,
     d->withoutTagCheckBox = new QCheckBox(notTaggedTitle, this);
     d->withoutTagCheckBox->setWhatsThis(i18n("Show images without a tag."));
 
-    QLabel *matchingConditionLabel = new QLabel(i18n("Matching Condition:"), this);
+    QLabel* matchingConditionLabel = new QLabel(i18n("Matching Condition:"), this);
     matchingConditionLabel->setWhatsThis(i18n(
-                    "Defines in which way the selected tags are combined to filter the images. "
-                    "This also includes the '%1' check box.", notTaggedTitle));
+            "Defines in which way the selected tags are combined to filter the images. "
+            "This also includes the '%1' check box.", notTaggedTitle));
 
     d->matchingConditionComboBox = new KComboBox(this);
     d->matchingConditionComboBox->setWhatsThis(matchingConditionLabel->whatsThis());
     d->matchingConditionComboBox->addItem(i18n("AND"), ImageFilterSettings::AndCondition);
     d->matchingConditionComboBox->addItem(i18n("OR"), ImageFilterSettings::OrCondition);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    QVBoxLayout* layout = new QVBoxLayout(this);
 
     layout->addWidget(d->tagFilterView);
     layout->addWidget(d->tagFilterSearchBar);
@@ -231,11 +228,11 @@ TagFilterSideBarWidget::TagFilterSideBarWidget(QWidget *parent,
 
     connect(d->matchingConditionComboBox, SIGNAL(currentIndexChanged(int)),
             this, SLOT(slotMatchingConditionChanged(int)));
-
 }
 
 TagFilterSideBarWidget::~TagFilterSideBarWidget()
 {
+    delete d;
 }
 
 void TagFilterSideBarWidget::slotResetTagFilters()
@@ -250,7 +247,8 @@ void TagFilterSideBarWidget::slotMatchingConditionChanged(int index)
     filterChanged();
 }
 
-void TagFilterSideBarWidget::slotCheckedTagsChanged(const QList<TAlbum*> &includedTags, const QList<TAlbum*> &excludedTags)
+void TagFilterSideBarWidget::slotCheckedTagsChanged(const QList<TAlbum*>& includedTags, 
+                                                    const QList<TAlbum*>& excludedTags)
 {
     Q_UNUSED(includedTags);
     Q_UNUSED(excludedTags);
@@ -267,21 +265,22 @@ void TagFilterSideBarWidget::filterChanged()
 {
     bool showUntagged = d->withoutTagCheckBox->checkState() == Qt::Checked;
     ImageFilterSettings::MatchingCondition matchCond =
-                (ImageFilterSettings::MatchingCondition)d->matchingConditionComboBox->itemData(
-                            d->matchingConditionComboBox->currentIndex()).toInt();
+        (ImageFilterSettings::MatchingCondition)d->matchingConditionComboBox->itemData(
+            d->matchingConditionComboBox->currentIndex()).toInt();
 
     QList<int> includedTagIds;
     QList<int> excludedTagIds;
+
     if (!showUntagged || matchCond == ImageFilterSettings::OrCondition)
     {
-        foreach(TAlbum *tag, d->tagFilterView->getCheckedTags())
+        foreach (TAlbum* tag, d->tagFilterView->getCheckedTags())
         {
             if (tag)
             {
                 includedTagIds << tag->id();
             }
         }
-        foreach(TAlbum *tag, d->tagFilterView->getPartiallyCheckedTags())
+        foreach (TAlbum* tag, d->tagFilterView->getPartiallyCheckedTags())
         {
             if (tag)
             {
@@ -302,13 +301,13 @@ void TagFilterSideBarWidget::setConfigGroup(KConfigGroup group)
 void TagFilterSideBarWidget::doLoadState()
 {
     d->matchingConditionComboBox->setCurrentIndex(getConfigGroup().readEntry(
-                    entryName(d->configMatchingConditionEntry), 0));
+                entryName(d->configMatchingConditionEntry), 0));
     d->tagFilterView->loadState();
 
     if (d->tagFilterView->isRestoreCheckState())
     {
         d->withoutTagCheckBox->setChecked(getConfigGroup().readEntry(entryName(
-                        d->configLastShowUntaggedEntry), false));
+                                              d->configLastShowUntaggedEntry), false));
     }
 
     filterChanged();
@@ -317,11 +316,11 @@ void TagFilterSideBarWidget::doLoadState()
 void TagFilterSideBarWidget::doSaveState()
 {
     getConfigGroup().writeEntry(entryName(d->configMatchingConditionEntry),
-                    d->matchingConditionComboBox->currentIndex());
+                                d->matchingConditionComboBox->currentIndex());
     d->tagFilterView->saveState();
     getConfigGroup().writeEntry(entryName(d->configLastShowUntaggedEntry),
-                        d->withoutTagCheckBox->isChecked());
+                                d->withoutTagCheckBox->isChecked());
     getConfigGroup().sync();
 }
 
-}
+} // namespace Digikam
