@@ -87,7 +87,7 @@ public:
         cInput(0),
         strengthInput(0),
         curvesBox(0)
-        {}
+    {}
 
     static const QString       configSettingsTabEntry;
     static const QString       configBWFilterEntry;
@@ -121,11 +121,17 @@ const QString BWSepiaSettings::BWSepiaSettingsPriv::configCurveEntry("BWSepiaCur
 // --------------------------------------------------------
 
 BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
-               : QWidget(parent),
-                 d(new BWSepiaSettingsPriv)
+    : QWidget(parent),
+      d(new BWSepiaSettingsPriv)
 {
-    if (!img->isNull()) d->thumbImage = img->smoothScale(128, 128, Qt::KeepAspectRatio);
-    else                d->thumbImage = DImg(DesktopIcon("image-x-generic", 128).toImage());
+    if (!img->isNull())
+    {
+        d->thumbImage = img->smoothScale(128, 128, Qt::KeepAspectRatio);
+    }
+    else
+    {
+        d->thumbImage = DImg(DesktopIcon("image-x-generic", 128).toImage());
+    }
 
     QGridLayout* grid = new QGridLayout(parent);
 
@@ -139,77 +145,77 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
 
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18nc("generic black and white film", "Generic"), type);
     item->setWhatsThis(i18n("<b>Generic</b>:"
-                               "<p>Simulate a generic black and white film.</p>"));
+                            "<p>Simulate a generic black and white film.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Agfa 200X"), type);
     item->setWhatsThis(i18n("<b>Agfa 200X</b>:"
-                               "<p>Simulate the Agfa 200X black and white film at 200 ISO.</p>"));
+                            "<p>Simulate the Agfa 200X black and white film at 200 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Agfa Pan 25"), type);
     item->setWhatsThis(i18n("<b>Agfa Pan 25</b>:"
-                               "<p>Simulate the Agfa Pan black and white film at 25 ISO.</p>"));
+                            "<p>Simulate the Agfa Pan black and white film at 25 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Agfa Pan 100"), type);
     item->setWhatsThis(i18n("<b>Agfa Pan 100</b>:"
-                               "<p>Simulate the Agfa Pan black and white film at 100 ISO.</p>"));
+                            "<p>Simulate the Agfa Pan black and white film at 100 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Agfa Pan 400"), type);
     item->setWhatsThis(i18n("<b>Agfa Pan 400</b>:"
-                               "<p>Simulate the Agfa Pan black and white film at 400 ISO.</p>"));
+                            "<p>Simulate the Agfa Pan black and white film at 400 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford Delta 100"), type);
     item->setWhatsThis(i18n("<b>Ilford Delta 100</b>:"
-                               "<p>Simulate the Ilford Delta black and white film at 100 ISO.</p>"));
+                            "<p>Simulate the Ilford Delta black and white film at 100 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford Delta 400"), type);
     item->setWhatsThis(i18n("<b>Ilford Delta 400</b>:"
-                               "<p>Simulate the Ilford Delta black and white film at 400 ISO.</p>"));
+                            "<p>Simulate the Ilford Delta black and white film at 400 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford Delta 400 Pro 3200"), type);
     item->setWhatsThis(i18n("<b>Ilford Delta 400 Pro 3200</b>:"
-                               "<p>Simulate the Ilford Delta 400 Pro black and white film at 3200 ISO.</p>"));
+                            "<p>Simulate the Ilford Delta 400 Pro black and white film at 3200 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford FP4 Plus"), type);
     item->setWhatsThis(i18n("<b>Ilford FP4 Plus</b>:"
-                               "<p>Simulate the Ilford FP4 Plus black and white film at 125 ISO.</p>"));
+                            "<p>Simulate the Ilford FP4 Plus black and white film at 125 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford HP5 Plus"), type);
     item->setWhatsThis(i18n("<b>Ilford HP5 Plus</b>:"
-                               "<p>Simulate the Ilford HP5 Plus black and white film at 400 ISO.</p>"));
+                            "<p>Simulate the Ilford HP5 Plus black and white film at 400 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford PanF Plus"), type);
     item->setWhatsThis(i18n("<b>Ilford PanF Plus</b>:"
-                               "<p>Simulate the Ilford PanF Plus black and white film at 50 ISO.</p>"));
+                            "<p>Simulate the Ilford PanF Plus black and white film at 50 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford XP2 Super"), type);
     item->setWhatsThis(i18n("<b>Ilford XP2 Super</b>:"
-                               "<p>Simulate the Ilford XP2 Super black and white film at 400 ISO.</p>"));
+                            "<p>Simulate the Ilford XP2 Super black and white film at 400 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Kodak Tmax 100"), type);
     item->setWhatsThis(i18n("<b>Kodak Tmax 100</b>:"
-                               "<p>Simulate the Kodak Tmax black and white film at 100 ISO.</p>"));
+                            "<p>Simulate the Kodak Tmax black and white film at 100 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Kodak Tmax 400"), type);
     item->setWhatsThis(i18n("<b>Kodak Tmax 400</b>:"
-                               "<p>Simulate the Kodak Tmax black and white film at 400 ISO.</p>"));
+                            "<p>Simulate the Kodak Tmax black and white film at 400 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Kodak TriX"), type);
     item->setWhatsThis(i18n("<b>Kodak TriX</b>:"
-                               "<p>Simulate the Kodak TriX black and white film at 400 ISO.</p>"));
+                            "<p>Simulate the Kodak TriX black and white film at 400 ISO.</p>"));
 
     // -------------------------------------------------------------
 
@@ -217,17 +223,17 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
 
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford SPX 200"), type);
     item->setWhatsThis(i18n("<b>Ilford SPX 200</b>:"
-                               "<p>Simulate the Ilford SPX infrared film at 200 ISO.</p>"));
+                            "<p>Simulate the Ilford SPX infrared film at 200 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford SPX 400"), type);
     item->setWhatsThis(i18n("<b>Ilford SPX 400</b>:"
-                               "<p>Simulate the Ilford SPX infrared film at 400 ISO.</p>"));
+                            "<p>Simulate the Ilford SPX infrared film at 400 ISO.</p>"));
 
     ++type;
     item = d->bwFilm->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Ilford SPX 800"), type);
     item->setWhatsThis(i18n("<b>Ilford SPX 800</b>:"
-                               "<p>Simulate the Ilford SPX infrared film at 800 ISO.</p>"));
+                            "<p>Simulate the Ilford SPX infrared film at 800 ISO.</p>"));
 
     // -------------------------------------------------------------
 
@@ -238,50 +244,50 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
     type = BWSepiaContainer::BWNoFilter;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("No Lens Filter"), type);
     item->setWhatsThis(i18n("<b>No Lens Filter</b>:"
-                               "<p>Do not apply a lens filter when rendering the image.</p>"));
+                            "<p>Do not apply a lens filter when rendering the image.</p>"));
 
     ++type;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Green Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Green Filter</b>:"
-                               "<p>Simulate black and white film exposure using a green filter. "
-                               "This is useful for all scenic shoots, especially "
-                               "portraits photographed against the sky.</p>"));
+                            "<p>Simulate black and white film exposure using a green filter. "
+                            "This is useful for all scenic shoots, especially "
+                            "portraits photographed against the sky.</p>"));
 
     ++type;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Orange Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Orange Filter</b>:"
-                               "<p>Simulate black and white film exposure using an orange filter. "
-                               "This will enhance landscapes, marine scenes and aerial "
-                               "photography.</p>"));
+                            "<p>Simulate black and white film exposure using an orange filter. "
+                            "This will enhance landscapes, marine scenes and aerial "
+                            "photography.</p>"));
 
     ++type;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Red Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Red Filter</b>:"
-                               "<p>Simulate black and white film exposure using a red filter. "
-                               "This creates dramatic sky effects, and simulates moonlight scenes "
-                               "in the daytime.</p>"));
+                            "<p>Simulate black and white film exposure using a red filter. "
+                            "This creates dramatic sky effects, and simulates moonlight scenes "
+                            "in the daytime.</p>"));
 
     ++type;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Yellow Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Yellow Filter</b>:"
-                               "<p>Simulate black and white film exposure using a yellow filter. "
-                               "This has the most natural tonal correction, and improves contrast. Ideal for "
-                               "landscapes.</p>"));
+                            "<p>Simulate black and white film exposure using a yellow filter. "
+                            "This has the most natural tonal correction, and improves contrast. Ideal for "
+                            "landscapes.</p>"));
 
     ++type;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Yellow-Green Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Yellow-Green Filter</b>:"
-                               "<p>Simulate black and white film exposure using a yellow-green filter. "
-                               "A yellow-green filter is highly effective for outdoor portraits because "
-                               "red is rendered dark while green appears lighter. Great for correcting skin tones, "
-                               "bringing out facial expressions in close-ups and emphasizing the feeling of liveliness. "
-                               "This filter is highly effective for indoor portraits under tungsten lighting.</p>"));
+                            "<p>Simulate black and white film exposure using a yellow-green filter. "
+                            "A yellow-green filter is highly effective for outdoor portraits because "
+                            "red is rendered dark while green appears lighter. Great for correcting skin tones, "
+                            "bringing out facial expressions in close-ups and emphasizing the feeling of liveliness. "
+                            "This filter is highly effective for indoor portraits under tungsten lighting.</p>"));
 
     ++type;
     item = d->bwFilters->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Blue Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Blue Filter</b>:"
-                               "<p>Simulate black and white film exposure using a blue filter. "
-                               "This accentuates haze and fog. Used for dye transfer and contrast effects.</p>"));
+                            "<p>Simulate black and white film exposure using a blue filter. "
+                            "This accentuates haze and fog. Used for dye transfer and contrast effects.</p>"));
 
     d->strengthInput = new RIntNumInput(vbox);
     d->strengthInput->input()->setLabel(i18n("Strength:"), Qt::AlignLeft | Qt::AlignVCenter);
@@ -302,51 +308,59 @@ BWSepiaSettings::BWSepiaSettings(QWidget* parent, DImg* img)
     type = BWSepiaContainer::BWNoTone;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("No Tone Filter"), type);
     item->setWhatsThis(i18n("<b>No Tone Filter</b>:"
-                               "<p>Do not apply a tone filter to the image.</p>"));
+                            "<p>Do not apply a tone filter to the image.</p>"));
 
     ++type;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Sepia Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Sepia Tone</b>:"
-                               "<p>Gives a warm highlight and mid-tone while adding a bit of coolness to "
-                               "the shadows - very similar to the process of bleaching a print and "
-                               "re-developing in a sepia toner.</p>"));
+                            "<p>Gives a warm highlight and mid-tone while adding a bit of coolness to "
+                            "the shadows - very similar to the process of bleaching a print and "
+                            "re-developing in a sepia toner.</p>"));
 
     ++type;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Brown Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Brown Tone</b>:"
-                               "<p>This filter is more neutral than the Sepia Tone "
-                               "filter.</p>"));
+                            "<p>This filter is more neutral than the Sepia Tone "
+                            "filter.</p>"));
 
     ++type;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Cold Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Cold Tone</b>:"
-                               "<p>Start subtly and replicate printing on a cold tone black and white "
-                               "paper such as a bromide enlarging "
-                               "paper.</p>"));
+                            "<p>Start subtly and replicate printing on a cold tone black and white "
+                            "paper such as a bromide enlarging "
+                            "paper.</p>"));
 
     ++type;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Selenium Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Selenium Tone</b>:"
-                               "<p>This effect replicates traditional selenium chemical toning done "
-                               "in the darkroom.</p>"));
+                            "<p>This effect replicates traditional selenium chemical toning done "
+                            "in the darkroom.</p>"));
 
     ++type;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Platinum Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with Platinum Tone</b>:"
-                               "<p>This effect replicates traditional platinum chemical toning done "
-                               "in the darkroom.</p>"));
+                            "<p>This effect replicates traditional platinum chemical toning done "
+                            "in the darkroom.</p>"));
 
     ++type;
     item = d->bwTone->addItem(new BWSepiaFilter(&d->thumbImage, 0, BWSepiaContainer(type, ccontainer)), i18n("Green Filter"), type);
     item->setWhatsThis(i18n("<b>Black & White with greenish tint</b>:"
-                               "<p>This effect is also known as Verdante.</p>"));
+                            "<p>This effect is also known as Verdante.</p>"));
 
     // -------------------------------------------------------------
 
     QWidget* lumBox = new QWidget();
+
     // NOTE: add a method to be able to use curves widget without image data as simple curve editor.
-    if (!img->isNull()) d->curvesBox = new CurvesBox(256, 192, img->bits(), img->width(), img->height(), img->sixteenBit(), lumBox);
-    else                d->curvesBox = new CurvesBox(256, 192, (uchar*)"\x00\x00\x00\x00\x00\x00\x00\x00", 1, 1, true, lumBox);
+    if (!img->isNull())
+    {
+        d->curvesBox = new CurvesBox(256, 192, img->bits(), img->width(), img->height(), img->sixteenBit(), lumBox);
+    }
+    else
+    {
+        d->curvesBox = new CurvesBox(256, 192, (uchar*)"\x00\x00\x00\x00\x00\x00\x00\x00", 1, 1, true, lumBox);
+    }
+
     d->curvesBox->enableCurveTypes(true);
     d->curvesBox->enableResetButton(true);
     d->curvesBox->setWhatsThis(i18n("This is the curve adjustment of the image luminosity"));
@@ -424,10 +438,15 @@ void BWSepiaSettings::startPreviewFilters()
 void BWSepiaSettings::slotFilterSelected()
 {
     int filter = d->bwFilters->currentId();
+
     if (filter == BWSepiaContainer::BWNoFilter)
+    {
         d->strengthInput->setEnabled(false);
+    }
     else
+    {
         d->strengthInput->setEnabled(true);
+    }
 
     emit signalSettingsChanged();
 }
@@ -528,8 +547,11 @@ void BWSepiaSettings::loadSettings()
     KUrl loadFile = KFileDialog::getOpenUrl(KGlobalSettings::documentPath(),
                                             QString( "*" ), kapp->activeWindow(),
                                             QString( i18n("Black & White Settings File to Load")) );
+
     if ( loadFile.isEmpty() )
-       return;
+    {
+        return;
+    }
 
     QFile file(loadFile.toLocalFile());
 
@@ -539,11 +561,11 @@ void BWSepiaSettings::loadSettings()
 
         if ( stream.readLine() != "# Black & White Configuration File" )
         {
-           KMessageBox::error(kapp->activeWindow(),
-                        i18n("\"%1\" is not a Black & White settings text file.",
-                             loadFile.fileName()));
-           file.close();
-           return;
+            KMessageBox::error(kapp->activeWindow(),
+                               i18n("\"%1\" is not a Black & White settings text file.",
+                                    loadFile.fileName()));
+            file.close();
+            return;
         }
 
         blockSignals(true);
@@ -554,7 +576,9 @@ void BWSepiaSettings::loadSettings()
         d->cInput->setValue(stream.readLine().toInt());
 
         for (int i = 0 ; i < 5 ; ++i)
+        {
             d->curvesBox->curves()->curvesChannelReset(i);
+        }
 
         d->curvesBox->curves()->setCurveType(d->curvesBox->channel(), ImageCurves::CURVE_SMOOTH);
         d->curvesBox->reset();
@@ -578,7 +602,9 @@ void BWSepiaSettings::loadSettings()
         }
 
         for (int i = 0 ; i < ImageCurves::NUM_CHANNELS ; ++i)
+        {
             d->curvesBox->curves()->curvesCalculateCurve(i);
+        }
 
         blockSignals(false);
     }
@@ -595,8 +621,11 @@ void BWSepiaSettings::saveAsSettings()
     KUrl saveFile = KFileDialog::getSaveUrl(KGlobalSettings::documentPath(),
                                             QString( "*" ), kapp->activeWindow(),
                                             QString( i18n("Black & White Settings File to Save")) );
+
     if ( saveFile.isEmpty() )
-       return;
+    {
+        return;
+    }
 
     QFile file(saveFile.toLocalFile());
 
@@ -613,11 +642,13 @@ void BWSepiaSettings::saveAsSettings()
         for (int j = 0 ; j < ImageCurves::NUM_POINTS ; ++j)
         {
             QPoint p = d->curvesBox->curves()->getCurvePoint(LuminosityChannel, j);
+
             if (d->curvesBox->curves()->isSixteenBits())
             {
                 p.setX(p.x()/ImageCurves::MULTIPLIER_16BIT);
                 p.setY(p.y()/ImageCurves::MULTIPLIER_16BIT);
             }
+
             stream << p.x() << "\n";
             stream << p.y() << "\n";
         }
