@@ -80,10 +80,10 @@ public:
     ImageDescEditTab*     desceditTab;
 };
 
-ImagePropertiesSideBarDB::ImagePropertiesSideBarDB(QWidget *parent, SidebarSplitter *splitter,
-                                                   KMultiTabBarPosition side, bool mimimizedDefault)
-                        : ImagePropertiesSideBar(parent, splitter, side, mimimizedDefault),
-                          d(new ImagePropertiesSideBarDBPriv)
+ImagePropertiesSideBarDB::ImagePropertiesSideBarDB(QWidget* parent, SidebarSplitter* splitter,
+        KMultiTabBarPosition side, bool mimimizedDefault)
+    : ImagePropertiesSideBar(parent, splitter, side, mimimizedDefault),
+      d(new ImagePropertiesSideBarDBPriv)
 {
     d->desceditTab = new ImageDescEditTab(parent);
 
@@ -106,12 +106,12 @@ ImagePropertiesSideBarDB::ImagePropertiesSideBarDB(QWidget *parent, SidebarSplit
     connect(d->desceditTab, SIGNAL(signalPrevItem()),
             this, SIGNAL(signalPrevItem()));
 
-    DatabaseWatch *dbwatch = DatabaseAccess::databaseWatch();
+    DatabaseWatch* dbwatch = DatabaseAccess::databaseWatch();
 
     connect(dbwatch, SIGNAL(imageChange(const ImageChangeset&)),
             this, SLOT(slotImageChangeDatabase(const ImageChangeset&)));
 
-    ImageAttributesWatch *watch = ImageAttributesWatch::instance();
+    ImageAttributesWatch* watch = ImageAttributesWatch::instance();
 
     connect(watch, SIGNAL(signalFileMetadataChanged(const KUrl&)),
             this, SLOT(slotFileMetadataChanged(const KUrl&)));
@@ -123,27 +123,32 @@ ImagePropertiesSideBarDB::~ImagePropertiesSideBarDB()
 }
 
 void ImagePropertiesSideBarDB::itemChanged(const ImageInfo& info,
-                                           const QRect& rect, DImg *img)
+        const QRect& rect, DImg* img)
 {
     itemChanged(info.fileUrl(), info, rect, img);
 }
 
-void ImagePropertiesSideBarDB::itemChanged(const KUrl& url, const QRect& rect, DImg *img)
+void ImagePropertiesSideBarDB::itemChanged(const KUrl& url, const QRect& rect, DImg* img)
 {
     itemChanged(url, ImageInfo(), rect, img);
 }
 
 void ImagePropertiesSideBarDB::itemChanged(const KUrl& url, const ImageInfo& info,
-                                           const QRect& rect, DImg *img)
+        const QRect& rect, DImg* img)
 {
     if ( !url.isValid() )
+    {
         return;
+    }
 
     m_currentURL = url;
 
     ImageInfoList list;
+
     if (!info.isNull())
+    {
         list << info;
+    }
 
     itemChanged(list, rect, img);
 }
@@ -151,14 +156,16 @@ void ImagePropertiesSideBarDB::itemChanged(const KUrl& url, const ImageInfo& inf
 void ImagePropertiesSideBarDB::itemChanged(const ImageInfoList& infos)
 {
     if (infos.isEmpty())
+    {
         return;
+    }
 
     m_currentURL = infos.first().fileUrl();
 
     itemChanged(infos, QRect(), 0);
 }
 
-void ImagePropertiesSideBarDB::itemChanged(ImageInfoList infos, const QRect& rect, DImg *img)
+void ImagePropertiesSideBarDB::itemChanged(ImageInfoList infos, const QRect& rect, DImg* img)
 {
     m_currentRect = rect;
     m_image       = img;
@@ -215,7 +222,9 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
                 m_metadataTab->setCurrentData(data, m_currentURL.fileName());
             }
             else
+            {
                 m_metadataTab->setCurrentURL(m_currentURL);
+            }
 
             m_dirtyMetadataTab = true;
         }
@@ -252,7 +261,9 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
                 m_metadataTab->setCurrentData(data, m_currentURL.fileName());
             }
             else
+            {
                 m_metadataTab->setCurrentURL(m_currentURL);
+            }
 
             m_dirtyMetadataTab = true;
         }
@@ -269,6 +280,7 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
         else if (tab == m_gpsTab && !m_dirtyGpsTab)
         {
             ImagePosition pos = d->currentInfos.first().imagePosition();
+
             if (pos.isEmpty())
             {
                 m_gpsTab->setCurrentURL();
@@ -315,10 +327,12 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
         else if (tab == m_gpsTab && !m_dirtyGpsTab)
         {
             GPSInfoList list;
+
             for (ImageInfoList::const_iterator it = d->currentInfos.constBegin();
                  it != d->currentInfos.constEnd(); ++it)
             {
                 ImagePosition pos = (*it).imagePosition();
+
                 if (!pos.isEmpty())
                 {
                     GPSInfo info;
@@ -330,6 +344,7 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
                     list.append(info);
                 }
             }
+
             if (list.isEmpty())
             {
                 m_gpsTab->setCurrentURL();
@@ -338,6 +353,7 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
             {
                 m_gpsTab->setGPSInfoList(list);
             }
+
             m_dirtyGpsTab = true;
         }
     }
@@ -364,23 +380,33 @@ void ImagePropertiesSideBarDB::slotImageChangeDatabase(const ImageChangeset& cha
 {
     if (!d->currentInfos.isEmpty())
     {
-        QWidget *tab = getActiveTab();
-        if (!tab) return;
+        QWidget* tab = getActiveTab();
+
+        if (!tab)
+        {
+            return;
+        }
 
         if (tab == m_propertiesTab || tab == m_gpsTab)
         {
             ImageInfo& info = d->currentInfos.first();
+
             if (changeset.ids().contains(info.id()))
             {
                 // trigger an update, if changes touch the tab's information
                 DatabaseFields::Set set = changeset.changes();
+
                 if ( (set & DatabaseFields::ImagesAll) ||
                      (set & DatabaseFields::ImageInformationAll) ||
                      (set & DatabaseFields::ImageMetadataAll) ||
                      (set & DatabaseFields::ImageCommentsAll) )
+                {
                     m_dirtyPropertiesTab = false;
+                }
                 else if (set & DatabaseFields::ImagePositionsAll)
+                {
                     m_dirtyGpsTab = false;
+                }
 
                 if ( tab == m_propertiesTab || tab == m_gpsTab)
                 {
@@ -452,7 +478,7 @@ void ImagePropertiesSideBarDB::setImagePropertiesInformation(const KUrl& url)
             m_propertiesTab->setFileModifiedDate(str);
 
             str = QString("%1 (%2)").arg(KIO::convertSize(commonInfo.fileSize))
-                                    .arg(KGlobal::locale()->formatNumber(commonInfo.fileSize, 0));
+                  .arg(KGlobal::locale()->formatNumber(commonInfo.fileSize, 0));
             m_propertiesTab->setFileSize(str);
 
             //  These infos are not stored in DB
@@ -462,14 +488,17 @@ void ImagePropertiesSideBarDB::setImagePropertiesInformation(const KUrl& url)
             // -- Image Properties --------------------------------------------------
 
             if (commonInfo.width == 0 || commonInfo.height == 0)
+            {
                 str = i18n("Unknown");
+            }
             else
             {
                 QString mpixels;
                 mpixels.setNum(commonInfo.width * commonInfo.height / 1000000.0, 'f', 2);
                 str = i18nc("width x height (megapixels Mpx)", "%1x%2 (%3Mpx)",
-                           commonInfo.width, commonInfo.height, mpixels);
+                            commonInfo.width, commonInfo.height, mpixels);
             }
+
             m_propertiesTab->setImageDimensions(str);
             m_propertiesTab->setImageBitDepth(i18n("%1 bpp", commonInfo.colorDepth));
             m_propertiesTab->setImageColorMode(commonInfo.colorModel.isEmpty() ? unavailable : commonInfo.colorModel);
@@ -493,13 +522,17 @@ void ImagePropertiesSideBarDB::setImagePropertiesInformation(const KUrl& url)
                 m_propertiesTab->setPhotoDateTime(str);
             }
             else
+            {
                 m_propertiesTab->setPhotoDateTime(unavailable);
+            }
 
             m_propertiesTab->setPhotoLens(photoInfo.lens.isEmpty() ? unavailable : photoInfo.lens);
             m_propertiesTab->setPhotoAperture(photoInfo.aperture.isEmpty() ? unavailable : photoInfo.aperture);
 
             if (photoInfo.focalLength35.isEmpty())
+            {
                 m_propertiesTab->setPhotoFocalLength(photoInfo.focalLength.isEmpty() ? unavailable : photoInfo.focalLength);
+            }
             else
             {
                 str = i18n("%1 (35mm: %2)", photoInfo.focalLength, photoInfo.focalLength35);
@@ -510,11 +543,17 @@ void ImagePropertiesSideBarDB::setImagePropertiesInformation(const KUrl& url)
             m_propertiesTab->setPhotoSensitivity(photoInfo.sensitivity.isEmpty() ? unavailable : i18n("%1 ISO", photoInfo.sensitivity));
 
             if (photoInfo.exposureMode.isEmpty() && photoInfo.exposureProgram.isEmpty())
+            {
                 m_propertiesTab->setPhotoExposureMode(unavailable);
+            }
             else if (!photoInfo.exposureMode.isEmpty() && photoInfo.exposureProgram.isEmpty())
+            {
                 m_propertiesTab->setPhotoExposureMode(photoInfo.exposureMode);
+            }
             else if (photoInfo.exposureMode.isEmpty() && !photoInfo.exposureProgram.isEmpty())
+            {
                 m_propertiesTab->setPhotoExposureMode(photoInfo.exposureProgram);
+            }
             else
             {
                 str = QString("%1 / %2").arg(photoInfo.exposureMode).arg(photoInfo.exposureProgram);
