@@ -50,7 +50,7 @@ class DIGIKAM_EXPORT PreviewWidget : public Q3ScrollView
 
 public:
 
-    PreviewWidget(QWidget *parent=0);
+    PreviewWidget(QWidget* parent=0);
     ~PreviewWidget();
 
     void   setZoomFactor(double z);
@@ -77,6 +77,8 @@ Q_SIGNALS:
 
     void signalRightButtonClicked();
     void signalLeftButtonClicked();
+    void signalLeftButtonDoubleClicked();
+    void signalActivated();
     void signalShowNextImage();
     void signalShowPrevImage();
     void signalZoomFactorChanged(double);
@@ -118,21 +120,25 @@ protected:
     void   updateZoomAndSize(bool alwaysFitToWindow);
     void   clearCache();
     QRect  previewRect();
-    void   drawText(QPainter* p, const QRect& rect, const QString& text);
+    void   drawText(QPainter* p, const QPoint& corner, const QString& text);
+    void   startPanning(const QPoint& pos);
+    void   continuePanning(const QPoint& pos);
+    void   finishPanning();
 
     virtual void setContentsSize();
-    virtual void viewportPaintExtraData(){};
+    virtual void viewportPaintExtraData() {};
     virtual int  previewWidth()=0;
     virtual int  previewHeight()=0;
     virtual bool previewIsNull()=0;
     virtual void resetPreview()=0;
     virtual QImage previewToQImage() const =0;
-    virtual void paintPreview(QPixmap *pix, int sx, int sy, int sw, int sh)=0;
+    virtual void paintPreview(QPixmap* pix, int sx, int sy, int sw, int sh)=0;
     virtual void zoomFactorChanged(double zoom);
 
     // Re-implemented from parent class.
     virtual void resizeEvent(QResizeEvent*);
     virtual void viewportPaintEvent(QPaintEvent*);
+    virtual void contentsMouseDoubleClickEvent(QMouseEvent*);
     virtual void contentsMousePressEvent(QMouseEvent*);
     virtual void contentsMouseMoveEvent(QMouseEvent*);
     virtual void contentsMouseReleaseEvent(QMouseEvent*);
