@@ -37,9 +37,9 @@ namespace Digikam
 {
 
 CameraNameOption::CameraNameOption()
-                : Option(i18n("Camera"), i18n("Add the camera name"), SmallIcon("camera-photo"))
+    : Option(i18n("Camera"), i18n("Add the camera name"), SmallIcon("camera-photo"))
 {
-    QString token = "[cam]";
+    QString token("[cam]");
     addToken(token, i18n("Camera name"));
 
     QRegExp reg(escapeToken(token));
@@ -52,6 +52,7 @@ QString CameraNameOption::parseOperation(ParseSettings& settings)
     QString result;
 
     ImageInfo info(settings.fileUrl);
+
     if (!info.isNull())
     {
         result = info.photoInfoContainer().make + " " + info.photoInfoContainer().model;
@@ -63,12 +64,13 @@ QString CameraNameOption::parseOperation(ParseSettings& settings)
         QString model;
 
         DMetadata meta(settings.fileUrl.toLocalFile());
+
         if (!meta.isEmpty())
         {
             KExiv2::MetaDataMap dataMap;
             dataMap = meta.getExifTagsDataList(QStringList(), true);
 
-            foreach (const QString &key, dataMap.keys())
+            foreach (const QString& key, dataMap.keys())
             {
                 if (key.toLower().contains("exif.image.model"))
                 {
