@@ -6,7 +6,7 @@
  * Date        : 2009-08-08
  * Description : an option to provide date information to the parser
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,59 +43,52 @@
 namespace Digikam
 {
 
-const QString dateFormatLinkDescr = i18nc("date format settings", "format settings");
-const QString dateFormatLink      = QString("<a href='http://doc.trolltech.com/latest/qdatetime.html#toString'>%1</a>")
-                                           .arg(dateFormatLinkDescr);
+static const QString dateFormatLinkDescr = i18nc("date format settings", "format settings");
+static const QString dateFormatLink =
+    QString("<a href='http://doc.trolltech.com/latest/qdatetime.html#toString'>%1</a>").arg(dateFormatLinkDescr);
 
 // --------------------------------------------------------
 
 DateFormat::DateFormat()
 {
-    m_map.clear();
-
     m_map.insert(Standard, DateFormatDescriptor(QString("Standard"), QString("yyyyMMddThhmmss")));
     m_map.insert(ISO,      DateFormatDescriptor(QString("ISO"),      Qt::ISODate));
     m_map.insert(FullText, DateFormatDescriptor(QString("Text"),     Qt::TextDate));
-//    m_map.insert(Locale,   DateFormatDescriptor(QString("Locale"),   Qt::SystemLocaleShortDate));
+    //    m_map.insert(Locale,   DateFormatDescriptor(QString("Locale"),   Qt::SystemLocaleShortDate));
     m_map.insert(Custom,   DateFormatDescriptor(QString("Custom"),   QString("")));
 }
 
 QString DateFormat::identifier(Type type)
 {
-    DateFormatDescriptor desc = m_map.at((int)type);
-    return desc.first;
+    return m_map.at((int)type).first;
 }
 
 QVariant DateFormat::formatType(Type type)
 {
-    DateFormatDescriptor desc = m_map.at((int)type);
-    return desc.second;
+    return m_map.at((int)type).second;
 }
 
-QVariant DateFormat::formatType(QString identifier)
+QVariant DateFormat::formatType(const QString& identifier)
 {
-    QVariant v;
-    foreach (const DateFormatDescriptor& desc, m_map)
-    {
-        if (desc.first == identifier)
-        {
-            v = desc.second;
-            break;
-        }
-    }
-
     if (identifier.isEmpty())
     {
         return m_map.at(Standard).second;
     }
 
-    return v;
+    foreach (const DateFormatDescriptor& desc, m_map)
+    {
+        if (desc.first == identifier)
+        {
+            return desc.second;
+        }
+    }
+    return QVariant();
 }
 
 // --------------------------------------------------------
 
 DateOptionDialog::DateOptionDialog(Parseable* parent)
-                : ParseableDialog(parent), ui(new Ui::DateOptionDialogWidget)
+    : ParseableDialog(parent), ui(new Ui::DateOptionDialogWidget)
 {
     QWidget* mainWidget = new QWidget(this);
     ui->setupUi(mainWidget);
@@ -105,8 +98,8 @@ DateOptionDialog::DateOptionDialog(Parseable* parent)
     // fill the date source combobox
     ui->dateSourcePicker->addItem(i18nc("Get date information from the image", "Image"),
                                   QVariant(FromImage));
-//    ui->dateSourcePicker->addItem(i18nc("Get date information from the current date", "Current Date"),
-//                                  QVariant(CurrentDateTime));
+    //    ui->dateSourcePicker->addItem(i18nc("Get date information from the current date", "Current Date"),
+    //                                  QVariant(CurrentDateTime));
     ui->dateSourcePicker->addItem(i18nc("Set a fixed date", "Fixed Date"),
                                   QVariant(FixedDateTime));
 
@@ -127,7 +120,7 @@ DateOptionDialog::DateOptionDialog(Parseable* parent)
     ui->dateFormatLink->setText(dateFormatLink);
 
     QRegExp validRegExp("[^/]+");
-    QValidator *validator = new QRegExpValidator(validRegExp, this);
+    QValidator* validator = new QRegExpValidator(validRegExp, this);
     ui->customFormatInput->setValidator(validator);
     ui->customFormatInput->setClickMessage(i18n("Enter custom format"));
 
@@ -163,7 +156,7 @@ DateOptionDialog::DateSource DateOptionDialog::dateSource()
     bool ok    = true;
     int choice = v.toInt(&ok);
 
-    return (DateSource)choice;
+    return static_cast<DateSource>(choice);
 }
 
 QString DateOptionDialog::formattedDateTime(const QDateTime& date)
@@ -174,10 +167,11 @@ QString DateOptionDialog::formattedDateTime(const QDateTime& date)
     }
 
     DateFormat df;
-    QVariant v;
+    QVariant   v;
 
-    v = df.formatType((DateFormat::Type)ui->dateFormatPicker->currentIndex());
+    v = df.formatType(static_cast<DateFormat::Type>(ui->dateFormatPicker->currentIndex()));
     QString result;
+
     if (v.type() == QVariant::String)
     {
         result = date.toString(v.toString());
@@ -186,23 +180,20 @@ QString DateOptionDialog::formattedDateTime(const QDateTime& date)
     {
         result = date.toString((Qt::DateFormat)v.toInt());
     }
+
     return result;
 }
 
 void DateOptionDialog::slotDateSourceChanged(int index)
 {
     Q_UNUSED(index)
-
-    DateSource choice = dateSource();
-    ui->fixedDateContainer->setEnabled( (choice == FixedDateTime) );
+    ui->fixedDateContainer->setEnabled(dateSource() == FixedDateTime);
 }
 
 void DateOptionDialog::slotDateFormatChanged(int index)
 {
     bool custom = (index == DateFormat::Custom);
-
     ui->customFormatInput->setEnabled(custom);
-
     ui->dateFormatLink->setEnabled(custom);
     ui->dateFormatLink->setVisible(custom);
 
@@ -223,12 +214,12 @@ void DateOptionDialog::updateExampleLabel()
 // --------------------------------------------------------
 
 DateOption::DateOption()
-          : Option(i18n("Date && Time..."),
-                   i18n("Add date and time information"),
-                   SmallIcon("view-pim-calendar"))
+    : Option(i18n("Date && Time..."),
+             i18n("Add date and time information"),
+             SmallIcon("view-pim-calendar"))
 {
     addToken("[date]",            i18n("Date and time (standard format)"));
-//    addToken("[date:||key||]",    i18n("Date and time (||key|| = Standard|ISO|Text|Locale)"));
+    //    addToken("[date:||key||]",    i18n("Date and time (||key|| = Standard|ISO|Text|Locale)"));
     addToken("[date:||key||]",    i18n("Date and time (||key|| = Standard|ISO|Text)"));
     addToken("[date:||format||]", i18n("Date and time") + " (" +  dateFormatLink + ')');
 
@@ -239,15 +230,12 @@ DateOption::DateOption()
 
 QString DateOption::parseOperation(ParseSettings& settings)
 {
-    QString result;
-    DateFormat df;
-
     const QRegExp& reg = regExp();
 
     QString token = reg.cap(2);
 
     if ( !(token.isEmpty() || token.isNull()) &&
-          (token.startsWith('"') && token.endsWith('"'))
+         (token.startsWith('"') && token.endsWith('"'))
        )
     {
         token = token.remove(0, 1);
@@ -265,6 +253,7 @@ QString DateOption::parseOperation(ParseSettings& settings)
     {
         // lets try to re-read the file information
         ImageInfo info(settings.fileUrl);
+
         if (!info.isNull())
         {
             dateTime = info.dateTime();
@@ -284,7 +273,10 @@ QString DateOption::parseOperation(ParseSettings& settings)
         return QString();
     }
 
-    QVariant v = df.formatType(token);
+    QString    result;
+    DateFormat df;
+    QVariant   v = df.formatType(token);
+
     if (v.isNull())
     {
         result = dateTime.toString(token);
@@ -308,15 +300,13 @@ void DateOption::slotTokenTriggered(const QString& token)
 {
     Q_UNUSED(token)
 
-    QVariant v;
-    DateFormat df;
-    QString dateString;
-
-    QString tokenStr               = QString("[date:%1]");
     QPointer<DateOptionDialog> dlg = new DateOptionDialog(this);
 
+    QString dateString;
+
     if (dlg->exec() == KDialog::Accepted)
     {
+        DateFormat df;
         int index = dlg->ui->dateFormatPicker->currentIndex();
 
         // use custom date format?
@@ -326,8 +316,9 @@ void DateOption::slotTokenTriggered(const QString& token)
             date.setDate(dlg->ui->datePicker->date());
             date.setTime(dlg->ui->timePicker->time());
 
-            v = (index == DateFormat::Custom) ? dlg->ui->customFormatInput->text()
-                                              : df.formatType((DateFormat::Type)index);
+            QVariant v = (index == DateFormat::Custom)
+                         ? dlg->ui->customFormatInput->text()
+                         : df.formatType((DateFormat::Type)index);
 
             if (v.type() == QVariant::String)
             {
@@ -338,8 +329,11 @@ void DateOption::slotTokenTriggered(const QString& token)
                 dateString = date.toString((Qt::DateFormat)v.toInt());
             }
         }
-        else        // use predefined keywords for date formatting
+        // use predefined keywords for date formatting
+        else
         {
+            QString tokenStr = QString("[date:%1]");
+
             switch (index)
             {
                 case DateFormat::Standard:
