@@ -6,7 +6,7 @@
  * Date        : 2009-08-08
  * Description : an option to provide date information to the parser
  *
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,7 +37,7 @@
 
 namespace Ui
 {
-    class DateOptionDialogWidget;
+class DateOptionDialogWidget;
 }
 
 namespace Digikam
@@ -50,23 +50,26 @@ public:
     DateFormat();
     ~DateFormat() {};
 
-    typedef QPair<QString, QVariant> DateFormatDescriptor;
+    typedef QPair<QString, QVariant>    DateFormatDescriptor;
     typedef QList<DateFormatDescriptor> DateFormatMap;
     enum Type
     {
         Standard = 0,
         ISO,
         FullText,
-//        Locale,
+        //        Locale,
         Custom
     };
 
     QString  identifier(Type type);
 
     QVariant formatType(Type type);
-    QVariant formatType(QString identifier);
+    QVariant formatType(const QString& identifier);
 
-    DateFormatMap& map() { return m_map; };
+    DateFormatMap& map()
+    {
+        return m_map;
+    };
 
 private:
 
