@@ -48,16 +48,16 @@ class BatchSyncMetadataPriv
 {
 public:
 
-    BatchSyncMetadataPriv()
+    BatchSyncMetadataPriv() :
+        cancel(false),
+        everStarted(false),
+        running(false),
+        count(0),
+        imageInfoIndex(0),
+        album(0),
+        imageInfoJob(0),
+        direction(BatchSyncMetadata::WriteFromDatabaseToFile)
     {
-        cancel         = false;
-        running        = false;
-        everStarted    = false;
-        imageInfoJob   = 0;
-        album          = 0;
-        count          = 0;
-        imageInfoIndex = 0;
-        direction      = BatchSyncMetadata::WriteFromDatabaseToFile;
     }
 
     bool           cancel;
@@ -67,20 +67,20 @@ public:
     int            count;
     int            imageInfoIndex;
 
-    Album         *album;
+    Album*         album;
 
-    ImageInfoJob  *imageInfoJob;
+    ImageInfoJob*  imageInfoJob;
 
     ImageInfoList  imageInfoList;
 
     CollectionScanner scanner;
 
     BatchSyncMetadata::SyncDirection
-                   direction;
+    direction;
 };
 
-BatchSyncMetadata::BatchSyncMetadata(Album *album, SyncDirection direction, QObject* parent)
-                 : QObject(parent), d(new BatchSyncMetadataPriv)
+BatchSyncMetadata::BatchSyncMetadata(Album* album, SyncDirection direction, QObject* parent)
+    : QObject(parent), d(new BatchSyncMetadataPriv)
 {
     d->album = album;
     d->direction = direction;
@@ -91,7 +91,7 @@ BatchSyncMetadata::BatchSyncMetadata(Album *album, SyncDirection direction, QObj
 }
 
 BatchSyncMetadata::BatchSyncMetadata(const ImageInfoList& list, SyncDirection direction, QObject* parent)
-                 : QObject(parent), d(new BatchSyncMetadataPriv)
+    : QObject(parent), d(new BatchSyncMetadataPriv)
 {
     d->imageInfoList = list;
     d->direction = direction;
@@ -118,7 +118,9 @@ void BatchSyncMetadata::parseAlbum()
 void BatchSyncMetadata::slotComplete()
 {
     if (!d->running)
+    {
         emit startParsingList();
+    }
 }
 
 void BatchSyncMetadata::slotAlbumParsed(const ImageInfoList& list)
@@ -126,7 +128,9 @@ void BatchSyncMetadata::slotAlbumParsed(const ImageInfoList& list)
     d->imageInfoList << list;
 
     if (!d->running && !d->cancel)
+    {
         emit startParsingList();
+    }
 }
 
 void BatchSyncMetadata::parseList()
@@ -134,21 +138,29 @@ void BatchSyncMetadata::parseList()
     if (!d->everStarted)
     {
         QString message;
+
         if (d->direction == WriteFromDatabaseToFile)
+        {
             message = i18n("Synchronizing image metadata with database. Please wait...");
+        }
         else
+        {
             message = i18n("Updating database from image metadata. Please wait...");
+        }
+
         emit signalProgressBarMode(StatusProgressBar::CancelProgressBarMode, message);
 
         d->everStarted = true;
     }
 
     d->running = true;
+
     while (d->imageInfoIndex != d->imageInfoList.size() && !d->cancel)
     {
         parsePicture();
         kapp->processEvents();
     }
+
     d->running = false;
 
     if (d->cancel ||
@@ -185,8 +197,11 @@ void BatchSyncMetadata::parsePicture()
 void BatchSyncMetadata::slotAbort()
 {
     d->cancel = true;
+
     if (d->imageInfoJob)
+    {
         d->imageInfoJob->stop();
+    }
 }
 
 void BatchSyncMetadata::complete()
