@@ -62,11 +62,11 @@ class BatchThumbsGeneratorPriv
 {
 public:
 
-    BatchThumbsGeneratorPriv()
+    BatchThumbsGeneratorPriv() :
+        cancel(false),
+        rebuildAll(true),
+        thumbLoadThread(0)
     {
-        cancel          = false;
-        rebuildAll      = true;
-        thumbLoadThread = 0;
         duration.start();
     }
 
@@ -77,11 +77,11 @@ public:
 
     QStringList          allPicturesPath;
 
-    ThumbnailLoadThread *thumbLoadThread;
+    ThumbnailLoadThread* thumbLoadThread;
 };
 
 BatchThumbsGenerator::BatchThumbsGenerator(QWidget* /*parent*/, bool rebuildAll)
-                    : DProgressDlg(0), d(new BatchThumbsGeneratorPriv)
+    : DProgressDlg(0), d(new BatchThumbsGeneratorPriv)
 {
     d->thumbLoadThread = ThumbnailLoadThread::defaultThread();
     d->rebuildAll      = rebuildAll;
@@ -124,6 +124,7 @@ void BatchThumbsGenerator::slotRebuildThumbs()
         QHash<QString, int> filePaths = ThumbnailDatabaseAccess().db()->getFilePathsWithThumbnail();
 
         QStringList::iterator it = d->allPicturesPath.begin();
+
         while (it != d->allPicturesPath.end())
         {
             if (filePaths.contains(*it))
@@ -141,9 +142,11 @@ void BatchThumbsGenerator::slotRebuildThumbs()
 
     // remove non-image files from the list
     QStringList::iterator it = d->allPicturesPath.begin();
+
     while (it != d->allPicturesPath.end())
     {
         ImageInfo info((*it));
+
         if (info.category() != DatabaseItem::Image)
         {
             it = d->allPicturesPath.erase(it);
@@ -158,8 +161,8 @@ void BatchThumbsGenerator::slotRebuildThumbs()
 
     if (d->allPicturesPath.isEmpty())
     {
-       slotCancel();
-       return;
+        slotCancel();
+        return;
     }
 
     processOne();
@@ -191,18 +194,32 @@ void BatchThumbsGenerator::complete()
 
 void BatchThumbsGenerator::slotGotThumbnail(const LoadingDescription& desc, const QPixmap& pix)
 {
-    if (d->cancel || d->allPicturesPath.isEmpty()) return;
+    if (d->cancel || d->allPicturesPath.isEmpty())
+    {
+        return;
+    }
 
-    if (d->allPicturesPath.first() != desc.filePath) return;
+    if (d->allPicturesPath.first() != desc.filePath)
+    {
+        return;
+    }
 
     addedAction(pix, desc.filePath);
     advance(1);
+
     if (!d->allPicturesPath.isEmpty())
+    {
         d->allPicturesPath.removeFirst();
+    }
+
     if (d->allPicturesPath.isEmpty())
+    {
         complete();
+    }
     else
+    {
         processOne();
+    }
 }
 
 void BatchThumbsGenerator::slotCancel()
@@ -211,7 +228,7 @@ void BatchThumbsGenerator::slotCancel()
     done(Cancel);
 }
 
-void BatchThumbsGenerator::closeEvent(QCloseEvent *e)
+void BatchThumbsGenerator::closeEvent(QCloseEvent* e)
 {
     abort();
     e->accept();
