@@ -49,27 +49,30 @@ class ImageInfoJobPriv
 {
 public:
 
-    ImageInfoJobPriv()
+    ImageInfoJobPriv() :
+        job(0)
     {
-        job         = 0;
     }
 
-    KIO::TransferJob  *job;
+    KIO::TransferJob*  job;
 };
 
 ImageInfoJob::ImageInfoJob()
-            : d(new ImageInfoJobPriv)
+    : d(new ImageInfoJobPriv)
 {
 }
 
 ImageInfoJob::~ImageInfoJob()
 {
     if (d->job)
-       d->job->kill();
+    {
+        d->job->kill();
+    }
+
     delete d;
 }
 
-void ImageInfoJob::allItemsFromAlbum(Album *album)
+void ImageInfoJob::allItemsFromAlbum(Album* album)
 {
     if (d->job)
     {
@@ -78,7 +81,9 @@ void ImageInfoJob::allItemsFromAlbum(Album *album)
     }
 
     if (!album)
+    {
         return;
+    }
 
     ImageLister lister;
     d->job = lister.startListJob(album->databaseUrl());
@@ -120,7 +125,9 @@ void ImageInfoJob::slotResult(KJob* job)
 void ImageInfoJob::slotData(KIO::Job*, const QByteArray& data)
 {
     if (data.isEmpty())
+    {
         return;
+    }
 
     ImageInfoList itemsList;
     QDataStream   ds(data);
