@@ -67,7 +67,7 @@ public:
     void removeItem(const QString& folder, const QString& file);
     void setThumbnail(const QString& folder, const QString& filename, const QImage& image);
 
-    void ensureItemVisible(CameraIconItem *item);
+    void ensureItemVisible(CameraIconItem* item);
     void ensureItemVisible(const GPItemInfo& itemInfo);
     void ensureItemVisible(const QString& folder, const QString& file);
 
@@ -81,16 +81,16 @@ public:
     int countItemsByFolder(QString folder);
     int itemsDownloaded();
 
-    QPixmap itemBaseRegPixmap()    const;
-    QPixmap itemBaseSelPixmap()    const;
-    QPixmap newPicturePixmap()     const;
-    QPixmap downloadUnknowPixmap() const;
-    QPixmap progressPixmap()       const;
-    QPixmap lockedPixmap()         const;
-    QPixmap downloadedPixmap()     const;
-    QPixmap downloadFailedPixmap() const;
+    QPixmap itemBaseRegPixmap()     const;
+    QPixmap itemBaseSelPixmap()     const;
+    QPixmap newPicturePixmap()      const;
+    QPixmap downloadUnknownPixmap() const;
+    QPixmap progressPixmap()        const;
+    QPixmap lockedPixmap()          const;
+    QPixmap downloadedPixmap()      const;
+    QPixmap downloadFailedPixmap()  const;
 
-    QString defaultDownloadName(CameraIconItem *item);
+    QString defaultDownloadName(CameraIconItem* item);
 
     void itemsSelectionSizeInfo(unsigned long& fSize, unsigned long& dSize);
 
@@ -131,10 +131,10 @@ private Q_SLOTS:
 protected:
 
     void startDrag();
-    void contentsDragEnterEvent(QDragEnterEvent *e);
-    void contentsDropEvent(QDropEvent *e);
+    void contentsDragEnterEvent(QDragEnterEvent* e);
+    void contentsDropEvent(QDropEvent* e);
     void updateItemRectsPixmap();
-    bool acceptToolTip(IconItem *item, const QPoint& mousePos);
+    bool acceptToolTip(IconItem* item, const QPoint& mousePos);
 
 private:
 
