@@ -45,16 +45,16 @@ class AssistantDlgPriv
 {
 public:
 
-    AssistantDlgPriv()
+    AssistantDlgPriv() :
+        welcomePage(0),
+        collectionPage(0),
+        rawPage(0),
+        metadataPage(0),
+        previewPage(0),
+        openFilePage(0),
+        tooltipsPage(0),
+        startScanPage(0)
     {
-        welcomePage    = 0;
-        collectionPage = 0;
-        rawPage        = 0;
-        metadataPage   = 0;
-        previewPage    = 0;
-        openFilePage   = 0;
-        tooltipsPage   = 0;
-        startScanPage  = 0;
     }
 
     WelcomePage*    welcomePage;
@@ -68,7 +68,7 @@ public:
 };
 
 AssistantDlg::AssistantDlg(QWidget* parent)
-            : KAssistantDialog(parent), d(new AssistantDlgPriv)
+    : KAssistantDialog(parent), d(new AssistantDlgPriv)
 {
     setHelp("firstrundialog.anchor", "digikam");
 
@@ -110,8 +110,11 @@ void AssistantDlg::next()
     if (currentPage() == d->collectionPage->page())
     {
         if (!d->collectionPage->checkSettings())
+        {
             return;
+        }
     }
+
     KAssistantDialog::next();
 }
 
