@@ -163,7 +163,7 @@ public:
 };
 
 RawSettingsBox::RawSettingsBox(const KUrl& url, QWidget* parent)
-              : EditorToolSettings(parent), d(new RawSettingsBoxPriv)
+    : EditorToolSettings(parent), d(new RawSettingsBoxPriv)
 {
     setButtons(Default|Ok|Cancel);
     setTools(Histogram);
@@ -177,7 +177,7 @@ RawSettingsBox::RawSettingsBox(const KUrl& url, QWidget* parent)
     d->rawdecodingBox      = new QWidget(d->tabView);
     QGridLayout* rawGrid   = new QGridLayout(d->rawdecodingBox);
     d->decodingSettingsBox = new DcrawSettingsWidget(d->rawdecodingBox,
-                                 DcrawSettingsWidget::SIXTEENBITS | DcrawSettingsWidget::COLORSPACE);
+            DcrawSettingsWidget::SIXTEENBITS | DcrawSettingsWidget::COLORSPACE);
     d->decodingSettingsBox->setObjectName("RawSettingsBox Expander");
 
     KFileDialog* inputDlg  = d->decodingSettingsBox->inputProfileUrlEdit()->fileDialog();
@@ -247,7 +247,7 @@ RawSettingsBox::RawSettingsBox(const KUrl& url, QWidget* parent)
     d->fineExposureInput->setRange(-3.0, 3.0, 0.1);
     d->fineExposureInput->setDefaultValue(0.0);
     d->fineExposureInput->input()->setWhatsThis(i18n("This value in E.V will be used to perform "
-                                                     "an exposure compensation of the image."));
+            "an exposure compensation of the image."));
 
     advExposureLayout->addWidget(d->brightnessLabel,   0, 0, 1, 1);
     advExposureLayout->addWidget(d->brightnessInput,   0, 1, 1, 2);
@@ -358,7 +358,7 @@ RawSettingsBox::RawSettingsBox(const KUrl& url, QWidget* parent)
             this, SIGNAL(signalAbortPreview()));
 
     connect(d->decodingSettingsBox, SIGNAL(signalSettingsChanged()),
-            this, SIGNAL(signalDemosaicingChanged()));
+            this, SLOT(slotDemosaicingChanged()));
 
     connect(d->curveWidget, SIGNAL(signalCurvesChanged()),
             this, SIGNAL(signalPostProcessingChanged()));
@@ -385,11 +385,21 @@ RawSettingsBox::~RawSettingsBox()
     delete d;
 }
 
+void RawSettingsBox::slotDemosaicingChanged()
+{
+    enableUpdateBtn(true);
+}
+
 void RawSettingsBox::enableUpdateBtn(bool b)
 {
     d->updateBtn->setEnabled(b);
 }
 
+bool RawSettingsBox::updateBtnEnabled()
+{
+    return d->updateBtn->isEnabled();
+}
+
 void RawSettingsBox::setBusy(bool b)
 {
     d->decodingSettingsBox->setEnabled(!b);
@@ -436,11 +446,11 @@ void RawSettingsBox::readSettings()
     KConfigGroup group        = config->group(d->optionGroupName);
 
     histogramBox()->setChannel((ChannelType)group.readEntry(d->optionHistogramChannelEntry,
-                    (int) LuminosityChannel));
+                               (int) LuminosityChannel));
     histogramBox()->setScale((HistogramScale)group.readEntry(d->optionHistogramScaleEntry,
-                    (int) LogScaleHistogram));
+                             (int) LogScaleHistogram));
     curvesWidget()->setScaleType((HistogramScale)group.readEntry(d->optionHistogramScaleEntry,
-                    (int) LogScaleHistogram));
+                                 (int) LogScaleHistogram));
 
     d->decodingSettingsBox->readSettings(group);
 
@@ -490,7 +500,9 @@ DRawDecoding RawSettingsBox::settings() const
     settings.exposureComp = d->fineExposureInput->value();
 
     if (d->curveWidget->curves()->isDirty())
+    {
         settings.curveAdjust = d->curveWidget->curves()->getCurvePoints(LuminosityChannel);
+    }
 
     return settings;
 }
