@@ -48,16 +48,16 @@ class PreviewToolBar::PreviewToolBarPriv
 
 public:
 
-    PreviewToolBarPriv()
+    PreviewToolBarPriv() :
+        previewOriginalButton(0),
+        previewBothButtonVert(0),
+        previewBothButtonHorz(0),
+        previewDuplicateBothButtonVert(0),
+        previewDupplicateBothButtonHorz(0),
+        previewtargetButton(0),
+        previewToggleMouseOverButton(0),
+        previewButtons(0)
     {
-        previewButtons                  = 0;
-        previewOriginalButton           = 0;
-        previewBothButtonVert           = 0;
-        previewBothButtonHorz           = 0;
-        previewDuplicateBothButtonVert  = 0;
-        previewDupplicateBothButtonHorz = 0;
-        previewtargetButton             = 0;
-        previewToggleMouseOverButton    = 0;
     }
 
     QToolButton*  previewOriginalButton;
@@ -72,11 +72,11 @@ public:
 };
 
 PreviewToolBar::PreviewToolBar(QWidget* parent)
-              : QWidget(parent), d(new PreviewToolBarPriv)
+    : QWidget(parent), d(new PreviewToolBarPriv)
 {
     setAttribute(Qt::WA_DeleteOnClose);
 
-    QHBoxLayout *hlay = new QHBoxLayout(this);
+    QHBoxLayout* hlay = new QHBoxLayout(this);
     d->previewButtons = new QButtonGroup(this);
     d->previewButtons->setExclusive(true);
     hlay->setSpacing(0);
@@ -96,10 +96,10 @@ PreviewToolBar::PreviewToolBar(QWidget* parent)
     d->previewBothButtonVert->setIcon(QPixmap(KStandardDirs::locate("data", "digikam/data/bothvert.png")));
     d->previewBothButtonVert->setCheckable(true);
     d->previewBothButtonVert->setWhatsThis(i18n("If this option is enabled, the preview area will "
-                                                "split vertically. "
-                                                "A contiguous area of the image will be shown, "
-                                                "with one half from the original image, "
-                                                "the other half from the target image."));
+                                           "split vertically. "
+                                           "A contiguous area of the image will be shown, "
+                                           "with one half from the original image, "
+                                           "the other half from the target image."));
     d->previewBothButtonVert->setToolTip(i18n("Vertical split with contiguous image"));
 
     d->previewBothButtonHorz = new QToolButton(this);
@@ -108,10 +108,10 @@ PreviewToolBar::PreviewToolBar(QWidget* parent)
     d->previewBothButtonHorz->setIcon(QPixmap(KStandardDirs::locate("data", "digikam/data/bothhorz.png")));
     d->previewBothButtonHorz->setCheckable(true);
     d->previewBothButtonHorz->setWhatsThis(i18n("If this option is enabled, the preview area will "
-                                                "split horizontally. "
-                                                "A contiguous area of the image will be shown, "
-                                                "with one half from the original image, "
-                                                "the other half from the target image."));
+                                           "split horizontally. "
+                                           "A contiguous area of the image will be shown, "
+                                           "with one half from the original image, "
+                                           "the other half from the target image."));
     d->previewBothButtonHorz->setToolTip(i18n("Horizontal split with contiguous image"));
 
     d->previewDuplicateBothButtonVert = new QToolButton(this);
@@ -120,9 +120,9 @@ PreviewToolBar::PreviewToolBar(QWidget* parent)
     d->previewDuplicateBothButtonVert->setIcon(QPixmap(KStandardDirs::locate("data", "digikam/data/duplicatebothvert.png")));
     d->previewDuplicateBothButtonVert->setCheckable(true);
     d->previewDuplicateBothButtonVert->setWhatsThis(i18n("If this option is enabled, the preview area will "
-                                                         "split vertically. "
-                                                         "The same part of the original and the target image "
-                                                         "will be shown side by side."));
+            "split vertically. "
+            "The same part of the original and the target image "
+            "will be shown side by side."));
     d->previewDuplicateBothButtonVert->setToolTip(i18n("Vertical split with same image region"));
 
     d->previewDupplicateBothButtonHorz = new QToolButton(this);
@@ -131,9 +131,9 @@ PreviewToolBar::PreviewToolBar(QWidget* parent)
     d->previewDupplicateBothButtonHorz->setIcon(QPixmap(KStandardDirs::locate("data", "digikam/data/duplicatebothhorz.png")));
     d->previewDupplicateBothButtonHorz->setCheckable(true);
     d->previewDupplicateBothButtonHorz->setWhatsThis(i18n("If this option is enabled, the preview area will "
-                                                          "split horizontally. "
-                                                          "The same part of the original and the target image "
-                                                          "will be shown side by side."));
+            "split horizontally. "
+            "The same part of the original and the target image "
+            "will be shown side by side."));
     d->previewDupplicateBothButtonHorz->setToolTip(i18n("Horizontal split with same image region"));
 
     d->previewtargetButton = new QToolButton(this);
@@ -150,8 +150,8 @@ PreviewToolBar::PreviewToolBar(QWidget* parent)
     d->previewToggleMouseOverButton->setIcon(QPixmap(KStandardDirs::locate("data", "digikam/data/togglemouseover.png")));
     d->previewToggleMouseOverButton->setCheckable(true);
     d->previewToggleMouseOverButton->setWhatsThis(i18n("If this option is enabled, the original image will "
-                                                       "be shown when the mouse is over image area; otherwise, "
-                                                       "the target image will be shown."));
+            "be shown when the mouse is over image area; otherwise, "
+            "the target image will be shown."));
     d->previewToggleMouseOverButton->setToolTip(i18n("Mouse-over mode"));
 
     connect(d->previewButtons, SIGNAL(buttonReleased(int)),
@@ -183,6 +183,7 @@ void PreviewToolBar::setPreviewModeMask(int mask)
 
     // When we switch to another mask, check if current mode is valid.
     PreviewToolBar::PreviewMode mode = previewMode();
+
     if (d->previewButtons->button(mode))
     {
         if (!d->previewButtons->button(mode)->isEnabled())
@@ -203,12 +204,17 @@ void PreviewToolBar::setPreviewModeMask(int mask)
 void PreviewToolBar::setPreviewMode(PreviewMode mode)
 {
     if (d->previewButtons->button(mode))
+    {
         d->previewButtons->button(mode)->setChecked(true);
+    }
 }
 
 PreviewToolBar::PreviewMode PreviewToolBar::previewMode()
 {
-    if (!isEnabled()) return PreviewToolBar::NoPreviewMode;
+    if (!isEnabled())
+    {
+        return PreviewToolBar::NoPreviewMode;
+    }
 
     return((PreviewMode)d->previewButtons->checkedId());
 }
