@@ -6,7 +6,7 @@
  * Date        : 2008-11-28
  * Description : JPEG2000 image Converter batch tool.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,7 @@ namespace Digikam
 {
 
 Convert2JP2::Convert2JP2(QObject* parent)
-           : BatchTool("Convert2JP2", BaseTool, parent)
+    : BatchTool("Convert2JP2", ConvertTool, parent)
 {
     setToolTitle(i18n("Convert To JP2"));
     setToolDescription(i18n("A tool to convert images to JPEG-2000 format."));
@@ -84,7 +84,7 @@ void Convert2JP2::slotSettingsChanged()
     BatchToolSettings settings;
     settings.insert("quality",  m_settings->getCompressionValue());
     settings.insert("lossless", m_settings->getLossLessCompression());
-    setSettings(settings);
+    BatchTool::slotSettingsChanged(settings);
 }
 
 QString Convert2JP2::outputSuffix() const
@@ -94,7 +94,10 @@ QString Convert2JP2::outputSuffix() const
 
 bool Convert2JP2::toolOperations()
 {
-    if (!loadToDImg()) return false;
+    if (!loadToDImg())
+    {
+        return false;
+    }
 
     bool lossless = settings()["lossless"].toBool();
     image().setAttribute("quality", lossless ? 100 : settings()["quality"].toInt());
