@@ -78,24 +78,24 @@ public:
 
 public:
 
-    WaterMarkPriv()
+    WaterMarkPriv() :
+        textSettingsGroupBox(0),
+        imageSettingsGroupBox(0),
+        useImageRadioButton(0),
+        useTextRadioButton(0),
+        useBackgroundCheckBox(0),
+        imageFileUrlRequester(0),
+        textEdit(0),
+        comboBox(0),
+        fontChooserWidget(0),
+        fontColorButton(0),
+        backgroundColorButton(0),
+        textOpacity(0),
+        backgroundOpacity(0),
+        xMarginInput(0),
+        yMarginInput(0),
+        waterMarkSizePercent(0)
     {
-        textSettingsGroupBox  = 0;
-        imageSettingsGroupBox = 0;
-        useImageRadioButton   = 0;
-        useTextRadioButton    = 0;
-        imageFileUrlRequester = 0;
-        textEdit              = 0;
-        fontChooserWidget     = 0;
-        fontColorButton       = 0;
-        useBackgroundCheckBox = 0;
-        backgroundColorButton = 0;
-        textOpacity           = 0;
-        backgroundOpacity     = 0;
-        comboBox              = 0;
-        xMarginInput          = 0;
-        yMarginInput          = 0;
-        waterMarkSizePercent  = 0;
     }
 
     QGroupBox*     textSettingsGroupBox;
@@ -121,11 +121,11 @@ public:
 };
 
 WaterMark::WaterMark(QObject* parent)
-         : BatchTool("WaterMark", DecorateTool, parent),
-           d(new WaterMarkPriv)
+    : BatchTool("WaterMark", DecorateTool, parent),
+      d(new WaterMarkPriv)
 {
     setToolTitle(i18n("Add Watermark"));
-    setToolDescription(i18n("A tool to overlay an image or a text as a visible watermark"));
+    setToolDescription(i18n("A tool to overlay an image or text as a visible watermark"));
     setToolIcon(KIcon(SmallIcon("insert-text")));
 
     KVBox* vbox = new KVBox;
@@ -250,7 +250,7 @@ WaterMark::WaterMark(QObject* parent)
     d->waterMarkSizePercent->setRange(0, 100);
     d->waterMarkSizePercent->setValue(30);
     d->waterMarkSizePercent->setSliderEnabled(true);
-    d->waterMarkSizePercent->setWhatsThis(i18n("Size of watermark in percent of the marked image."));
+    d->waterMarkSizePercent->setWhatsThis(i18n("Size of watermark, as a percentage of the marked image."));
     label5->setText(i18n("Size (%):"));
 
     QLabel* label6  = new QLabel(vbox);
@@ -258,7 +258,7 @@ WaterMark::WaterMark(QObject* parent)
     d->xMarginInput->setRange(0, 100);
     d->xMarginInput->setValue(2);
     d->xMarginInput->setSliderEnabled(true);
-    d->xMarginInput->setWhatsThis(i18n("Margin from edge in X direction in percent of the marked image"));
+    d->xMarginInput->setWhatsThis(i18n("Margin from edge in X direction, as a percentage of the marked image"));
     label6->setText(i18n("X margin (%):"));
 
     QLabel* label7  = new QLabel(vbox);
@@ -266,7 +266,7 @@ WaterMark::WaterMark(QObject* parent)
     d->yMarginInput->setRange(0, 100);
     d->yMarginInput->setValue(2);
     d->yMarginInput->setSliderEnabled(true);
-    d->yMarginInput->setWhatsThis(i18n("Margin from edge in Y direction in percent of the marked image"));
+    d->yMarginInput->setWhatsThis(i18n("Margin from edge in Y direction, as a percentage of the marked image"));
     label7->setText(i18n("Y margin (%):"));
 
     QLabel* space = new QLabel(vbox);
@@ -399,7 +399,10 @@ void WaterMark::slotSettingsChanged()
 bool WaterMark::toolOperations()
 {
 
-    if (!loadToDImg()) return false;
+    if (!loadToDImg())
+    {
+        return false;
+    }
 
     QString fileName        = settings()["Watermark image"].toString();
     int placement           = settings()["Placement"].toInt();
@@ -428,7 +431,7 @@ bool WaterMark::toolOperations()
 
         if (watermarkImage.isNull())
         {
-          return false;
+            return false;
         }
 
         DImg tempImage = watermarkImage.smoothScale(image().width() * size / 100, image().height() * size / 100, Qt::KeepAspectRatio);
@@ -439,12 +442,19 @@ bool WaterMark::toolOperations()
         int alignMode;
         const int radius = 10;
 
-        if (text.isEmpty()) return false;
+        if (text.isEmpty())
+        {
+            return false;
+        }
 
         int fontSize = queryFontSize(text, font, size);
-        if (fontSize == 0) return false;
 
-        switch(placement)
+        if (fontSize == 0)
+        {
+            return false;
+        }
+
+        switch (placement)
         {
             case WaterMarkPriv::TopLeft:
                 alignMode = Qt::AlignLeft;
@@ -473,7 +483,12 @@ bool WaterMark::toolOperations()
         DImg backgroundLayer(backgroundRect.width(), backgroundRect.height(), image().sixteenBit(), true);
         DColor transparent(QColor(0, 0, 0));
         transparent.setAlpha(0);
-        if (image().sixteenBit()) transparent.convertToSixteenBit();
+
+        if (image().sixteenBit())
+        {
+            transparent.convertToSixteenBit();
+        }
+
         backgroundLayer.fill(transparent);
 
         DImg grayTransLayer(fontRect.width(), fontRect.height(), image().sixteenBit(), true);
@@ -482,7 +497,12 @@ bool WaterMark::toolOperations()
         {
             DColor grayTrans(backgroundColor);
             grayTrans.setAlpha(backgroundOpacity * 255 / 100);
-            if (image().sixteenBit()) grayTrans.convertToSixteenBit();
+
+            if (image().sixteenBit())
+            {
+                grayTrans.convertToSixteenBit();
+            }
+
             grayTransLayer.fill(grayTrans);
             backgroundLayer.bitBlendImage(composer, &grayTransLayer, 0, 0,
                                           grayTransLayer.width(), grayTransLayer.height(),
@@ -511,7 +531,7 @@ bool WaterMark::toolOperations()
 
     QRect watermarkRect(0,0,watermarkImage.width(), watermarkImage.height());
 
-    switch(placement)
+    switch (placement)
     {
         case WaterMarkPriv::TopLeft:
             watermarkRect.moveTopLeft(QPoint(marginW, marginH));
@@ -544,14 +564,19 @@ int WaterMark::queryFontSize(const QString& text, const QFont& font, int length)
     // Find font size using relative length compared to image width.
     QFont fnt = font;
     QRect fontRect;
+
     for (int i = 1 ; i <= 1000 ; ++i)
     {
         fnt.setPointSizeF(i);
         QFontMetrics fontMt(fnt);
         fontRect = fontMt.boundingRect(0, 0, image().width(), image().height(), 0, text);
+
         if (fontRect.width() > lround((image().width() * length)/100.0))
+        {
             return (i-1);
+        }
     }
+
     return 0;
 }
 
