@@ -102,7 +102,9 @@ QueueMgrWindow* QueueMgrWindow::m_instance = 0;
 QueueMgrWindow* QueueMgrWindow::queueManagerWindow()
 {
     if (!m_instance)
+    {
         new QueueMgrWindow();
+    }
 
     return m_instance;
 }
@@ -113,13 +115,14 @@ bool QueueMgrWindow::queueManagerWindowCreated()
 }
 
 QueueMgrWindow::QueueMgrWindow()
-              : KXmlGuiWindow(0), d(new QueueMgrWindowPriv)
+    : KXmlGuiWindow(0), d(new QueueMgrWindowPriv)
 {
     setXMLFile("queuemgrwindowui.rc");
 
     // --------------------------------------------------------
 
     UiFileValidator validator(localXMLFile());
+
     if (!validator.isValid())
     {
         validator.fixConfigFile();
@@ -175,7 +178,9 @@ BatchToolsManager* QueueMgrWindow::batchToolsManager() const
 QMap<int, QString> QueueMgrWindow::queuesMap() const
 {
     if (d->queuePool)
+    {
         return d->queuePool->queuesMap();
+    }
 
     return QMap<int, QString>();
 }
@@ -187,7 +192,10 @@ bool QueueMgrWindow::isBusy() const
 
 void QueueMgrWindow::closeEvent(QCloseEvent* e)
 {
-    if (!e) return;
+    if (!e)
+    {
+        return;
+    }
 
     writeSettings();
     e->accept();
@@ -499,7 +507,10 @@ void QueueMgrWindow::writeSettings()
 void QueueMgrWindow::applySettings()
 {
     // Do not apply general settings from config panel if BQM is busy.
-    if (d->busy) return;
+    if (d->busy)
+    {
+        return;
+    }
 
     AlbumSettings* settings   = AlbumSettings::instance();
     KSharedConfig::Ptr config = KGlobal::config();
@@ -518,23 +529,23 @@ void QueueMgrWindow::applySettings()
     DRawDecoding         rawDecodingSettings;
     ICCSettingsContainer ICCSettings = IccSettings::instance()->settings();
 
-    rawDecodingSettings.readSettings(group);
+    rawDecodingSettings.rawPrm.readSettings(group);
 
     if (ICCSettings.enableCM)
     {
         if (ICCSettings.defaultUncalibratedBehavior & ICCSettingsContainer::AutomaticColors)
         {
-            rawDecodingSettings.outputColorSpace = DRawDecoding::CUSTOMOUTPUTCS;
-            rawDecodingSettings.outputProfile    = ICCSettings.workspaceProfile;
+            rawDecodingSettings.rawPrm.outputColorSpace = RawDecodingSettings::CUSTOMOUTPUTCS;
+            rawDecodingSettings.rawPrm.outputProfile    = ICCSettings.workspaceProfile;
         }
         else
         {
-            rawDecodingSettings.outputColorSpace = DRawDecoding::RAWCOLOR;
+            rawDecodingSettings.rawPrm.outputColorSpace = RawDecodingSettings::RAWCOLOR;
         }
     }
     else
     {
-        rawDecodingSettings.outputColorSpace = DRawDecoding::SRGB;
+        rawDecodingSettings.rawPrm.outputColorSpace = RawDecodingSettings::SRGB;
     }
 
     d->thread->setRawDecodingSettings(rawDecodingSettings);
@@ -680,7 +691,9 @@ void QueueMgrWindow::slotToggleFullScreen()
 void QueueMgrWindow::slotEscapePressed()
 {
     if (d->fullScreen)
+    {
         d->fullScreenAction->activate(QAction::Trigger);
+    }
 }
 
 void QueueMgrWindow::showToolBars()
@@ -759,8 +772,11 @@ void QueueMgrWindow::slotThemeChanged()
 {
     QStringList themes(ThemeEngine::instance()->themeNames());
     int index = themes.indexOf(AlbumSettings::instance()->getCurrentTheme());
+
     if (index == -1)
+    {
         index = themes.indexOf(i18n("Default"));
+    }
 
     d->themeMenuAction->setCurrentItem(index);
 }
@@ -788,9 +804,9 @@ bool QueueMgrWindow::queryClose()
 {
     if (isBusy())
     {
-        int result = KMessageBox::warningYesNo(this, 
-                        i18n("Batch Queue Manager is running. Do you want to cancel current job?"),
-                        i18n("Processing under progress"));
+        int result = KMessageBox::warningYesNo(this,
+                                               i18n("Batch Queue Manager is running. Do you want to cancel current job?"),
+                                               i18n("Processing under progress"));
 
         if (result == KMessageBox::Yes)
         {
@@ -818,7 +834,11 @@ int QueueMgrWindow::currentQueueId()
 void QueueMgrWindow::loadImageInfos(const ImageInfoList& list, int queueId)
 {
     QueueListView* queue = d->queuePool->findQueueById(queueId);
-    if (queue) queue->slotAddItems(list);
+
+    if (queue)
+    {
+        queue->slotAddItems(list);
+    }
 }
 
 void QueueMgrWindow::slotQueueContentsChanged()
@@ -890,10 +910,14 @@ void QueueMgrWindow::slotStop()
     d->progressTimer->stop();
 
     if (d->currentProcessItem)
+    {
         d->currentProcessItem->setCanceled();
+    }
 
     if (d->currentTaskItem)
+    {
         d->currentTaskItem->setCanceled();
+    }
 
     d->itemsList.clear();
     d->thread->cancel();
@@ -923,6 +947,7 @@ void QueueMgrWindow::processOne()
 
     ItemInfoSet set = d->itemsList.first();
     d->queuePool->setCurrentIndex(set.queueId);
+
     if (!checkTargetAlbum(set.queueId))
     {
         processingAborted();
@@ -933,6 +958,7 @@ void QueueMgrWindow::processOne()
     AssignedBatchTools tools4Item = d->queuePool->currentQueue()->assignedTools();
     tools4Item.m_itemUrl          = set.info.fileUrl();
     QueueListViewItem* item       = d->queuePool->currentQueue()->findItemByUrl(tools4Item.m_itemUrl);
+
     if (item)
     {
         d->itemsList.removeFirst();
@@ -941,8 +967,11 @@ void QueueMgrWindow::processOne()
         {
             d->thread->setWorkingUrl(settings.targetUrl);
             d->thread->processFile(tools4Item);
+
             if (!d->thread->isRunning())
+            {
                 d->thread->start();
+            }
         }
         else
         {
@@ -953,7 +982,7 @@ void QueueMgrWindow::processOne()
 
 void QueueMgrWindow::slotAction(const ActionData& ad)
 {
-    switch(ad.status)
+    switch (ad.status)
     {
         case ActionData::BatchStarted:
         {
@@ -1016,13 +1045,23 @@ void QueueMgrWindow::slotAction(const ActionData& ad)
 void QueueMgrWindow::slotProgressTimerDone()
 {
     QPixmap ico(d->progressPix.copy(0, d->progressCount*22, 22, 22));
+
     if (d->currentProcessItem)
+    {
         d->currentProcessItem->setProgressIcon(ico);
+    }
+
     if (d->currentTaskItem)
+    {
         d->currentTaskItem->setProgressIcon(ico);
+    }
 
     d->progressCount++;
-    if (d->progressCount == 8) d->progressCount = 0;
+
+    if (d->progressCount == 8)
+    {
+        d->progressCount = 0;
+    }
 
     d->progressTimer->start(300);
 }
@@ -1030,6 +1069,7 @@ void QueueMgrWindow::slotProgressTimerDone()
 void QueueMgrWindow::processing(const KUrl& url)
 {
     d->currentProcessItem = d->queuePool->currentQueue()->findItemByUrl(url);
+
     if (d->currentProcessItem)
     {
         d->currentProcessItem->reset();
@@ -1053,10 +1093,11 @@ void QueueMgrWindow::processed(const KUrl& url, const KUrl& tmp)
     if (settings.conflictRule != QueueSettings::OVERWRITE)
     {
         struct stat statBuf;
+
         if (::stat(QFile::encodeName(dest.toLocalFile()), &statBuf) == 0)
         {
             KIO::RenameDialog dlg(this, i18n("Save Queued Image from '%1' as",
-                                  url.fileName()),
+                                             url.fileName()),
                                   tmp, dest,
                                   KIO::RenameDialog_Mode(KIO::M_SINGLE | KIO::M_OVERWRITE | KIO::M_SKIP));
 
@@ -1072,11 +1113,13 @@ void QueueMgrWindow::processed(const KUrl& url, const KUrl& tmp)
                 case KIO::R_SKIP:
                 {
                     dest = KUrl();
+
                     if (d->currentProcessItem)
                     {
                         d->currentProcessItem->setCanceled();
                         addHistoryMessage(i18n("Item skipped..."), DHistoryView::WarningEntry);
                     }
+
                     break;
                 }
                 case KIO::R_RENAME:
@@ -1140,7 +1183,9 @@ void QueueMgrWindow::processingFailed(const KUrl&, const QString& errMsg)
     }
 
     if (d->currentTaskItem)
+    {
         d->currentTaskItem->setCanceled();
+    }
 
     d->currentProcessItem = 0;
 }
@@ -1154,7 +1199,9 @@ void QueueMgrWindow::processingCanceled(const KUrl&)
     }
 
     if (d->currentTaskItem)
+    {
         d->currentTaskItem->setCanceled();
+    }
 
     d->currentProcessItem = 0;
 }
@@ -1231,8 +1278,11 @@ void QueueMgrWindow::slotAssignedToolsChanged(const AssignedBatchTools& tools)
 bool QueueMgrWindow::checkTargetAlbum(int queueId)
 {
     QueueListView* queue = d->queuePool->findQueueById(queueId);
+
     if (!queue)
+    {
         return false;
+    }
 
     QString queueName              = d->queuePool->queueTitle(queueId);
     KUrl    processedItemsAlbumUrl = queue->settings().targetUrl;
@@ -1241,9 +1291,9 @@ bool QueueMgrWindow::checkTargetAlbum(int queueId)
     if (processedItemsAlbumUrl.isEmpty())
     {
         KMessageBox::error(this,
-                        i18n("Album to host processed items from queue \"%1\" is not set. "
-                             "Please select one from Queue Settings panel.", queueName),
-                        i18n("Processed items album settings"));
+                           i18n("Album to host processed items from queue \"%1\" is not set. "
+                                "Please select one from Queue Settings panel.", queueName),
+                           i18n("Processed items album settings"));
         return false;
     }
 
@@ -1252,10 +1302,10 @@ bool QueueMgrWindow::checkTargetAlbum(int queueId)
     if ( !dir.exists() || !dir.isWritable() )
     {
         KMessageBox::error(this,
-                        i18n("Album to host processed items from queue \"%1\" "
-                             "is not available or not writable. "
-                             "Please set another one from Queue Settings panel.", queueName),
-                        i18n("Processed items album settings"));
+                           i18n("Album to host processed items from queue \"%1\" "
+                                "is not available or not writable. "
+                                "Please set another one from Queue Settings panel.", queueName),
+                           i18n("Processed items album settings"));
         return false;
     }
 
@@ -1286,12 +1336,17 @@ void QueueMgrWindow::addHistoryMessage(const QString& msg, DHistoryView::EntryTy
 
 void QueueMgrWindow::slotHistoryEntryClicked(int queueId, qlonglong itemId)
 {
-    if (d->busy) return;
+    if (d->busy)
+    {
+        return;
+    }
 
     QueueListView* view = d->queuePool->findQueueById(queueId);
+
     if (view)
     {
         QueueListViewItem* item = view->findItemById(itemId);
+
         if (item)
         {
             d->queuePool->setCurrentIndex(queueId);
