@@ -66,43 +66,42 @@ class Setup::SetupPrivate
 {
 public:
 
-    SetupPrivate()
+    SetupPrivate() :
+        page_database(0),
+        page_collections(0),
+        page_albumView(0),
+        page_tooltip(0),
+        page_metadata(0),
+        page_template(0),
+        page_category(0),
+        page_mime(0),
+        page_lighttable(0),
+        page_editor(0),
+        page_dcraw(0),
+        page_iofiles(0),
+        page_slideshow(0),
+        page_icc(0),
+        page_plugins(0),
+        page_camera(0),
+        page_misc(0),
+        databasePage(0),
+        collectionsPage(0),
+        albumViewPage(0),
+        tooltipPage(0),
+        metadataPage(0),
+        templatePage(0),
+        categoryPage(0),
+        mimePage(0),
+        lighttablePage(0),
+        editorPage(0),
+        dcrawPage(0),
+        iofilesPage(0),
+        slideshowPage(0),
+        iccPage(0),
+        cameraPage(0),
+        miscPage(0),
+        pluginsPage(0)
     {
-        page_database    = 0;
-        page_collections = 0;
-        page_albumView   = 0;
-        page_tooltip     = 0;
-        page_metadata    = 0;
-        page_template    = 0;
-        page_category    = 0;
-        page_mime        = 0;
-        page_lighttable  = 0;
-        page_editor      = 0;
-        page_dcraw       = 0;
-        page_iofiles     = 0;
-        page_slideshow   = 0;
-        page_icc         = 0;
-        page_plugins     = 0;
-        page_camera      = 0;
-        page_misc        = 0;
-
-        databasePage     = 0;
-        collectionsPage  = 0;
-        albumViewPage    = 0;
-        tooltipPage      = 0;
-        metadataPage     = 0;
-        templatePage     = 0;
-        categoryPage     = 0;
-        mimePage         = 0;
-        lighttablePage   = 0;
-        editorPage       = 0;
-        dcrawPage        = 0;
-        iofilesPage      = 0;
-        slideshowPage    = 0;
-        iccPage          = 0;
-        cameraPage       = 0;
-        miscPage         = 0;
-        pluginsPage      = 0;
     }
 
     KPageWidgetItem*  page_database;
@@ -147,7 +146,7 @@ public:
 };
 
 Setup::Setup(QWidget* parent)
-     : KPageDialog(parent), d(new SetupPrivate)
+    : KPageDialog(parent), d(new SetupPrivate)
 {
     setCaption(i18n("Configure"));
     setButtons(Help|Ok|Cancel );
@@ -159,7 +158,7 @@ Setup::Setup(QWidget* parent)
     d->databasePage     = new SetupDatabase(this);
     d->page_database    = addPage(d->databasePage, i18n("Database"));
     d->page_database->setHeader(i18n("<qt>Database Settings<br/>"
-                                   "<i>Customize database settings</i></qt>"));
+                                     "<i>Customize database settings</i></qt>"));
     d->page_database->setIcon(KIcon("server-database"));
 
     d->collectionsPage  = new SetupCollections(this);
@@ -261,12 +260,19 @@ Setup::Setup(QWidget* parent)
     for (int i = 0; i != SetupPageEnumLast; ++i)
     {
         KPageWidgetItem* item = d->pageItem((Page)i);
+
         if (!item)
+        {
             continue;
+        }
+
         QWidget* wgt            = item->widget();
         QScrollArea* scrollArea = qobject_cast<QScrollArea*>(wgt);
+
         if (scrollArea)
+        {
             scrollArea->setFrameShape(QFrame::NoFrame);
+        }
     }
 
     connect(this, SIGNAL(okClicked()),
@@ -292,7 +298,9 @@ Setup::~Setup()
 void Setup::setTemplate(const Template& t)
 {
     if (d->templatePage)
+    {
         d->templatePage->setTemplate(t);
+    }
 }
 
 QSize Setup::sizeHint() const
@@ -319,22 +327,29 @@ QSize Setup::sizeHint() const
             page == MiscellaneousPage)
         {
             KPageWidgetItem* item   = d->pageItem((Page)page);
+
             if (!item)
+            {
                 continue;
+            }
 
             QWidget* page           = item->widget();
             maxHintHeight           = qMax(maxHintHeight, page->sizeHint().height());
             QScrollArea* scrollArea = qobject_cast<QScrollArea*>(page);
 
             if (scrollArea)
+            {
                 maxWidgetHeight = qMax(maxWidgetHeight, scrollArea->widget()->sizeHint().height());
+            }
         }
     }
 
     // The additional 20 is a hack to make it work.
     // Don't know why, the largest page would have scroll bars without this
     if (maxWidgetHeight > maxHintHeight)
+    {
         hint.setHeight(hint.height() + (maxWidgetHeight - maxHintHeight) + 20);
+    }
 
     return hint;
 }
@@ -412,8 +427,11 @@ void Setup::slotOkClicked()
                            "Note: thumbnail processing can take a while. You can start "
                            "this job later from the \"Tools\" menu.");
         int result = KMessageBox::warningYesNo(this, msg);
+
         if (result != KMessageBox::Yes)
+        {
             return;
+        }
 
         BatchThumbsGenerator* thumbsGenerator = new BatchThumbsGenerator(this);
         thumbsGenerator->show();
@@ -425,6 +443,7 @@ void Setup::slotOkClicked()
 void Setup::showPage(Setup::Page page)
 {
     KPageWidgetItem* item = 0;
+
     if (page == LastPageUsed)
     {
         KSharedConfig::Ptr config = KGlobal::config();
@@ -438,7 +457,9 @@ void Setup::showPage(Setup::Page page)
     }
 
     if (!item)
+    {
         item = d->pageItem(CollectionsPage);
+    }
 
     setCurrentPage(item);
 }
@@ -447,29 +468,92 @@ Setup::Page Setup::activePageIndex()
 {
     KPageWidgetItem* cur = currentPage();
 
-    if (cur == d->page_collections) return CollectionsPage;
-    if (cur == d->page_albumView)   return AlbumViewPage;
-    if (cur == d->page_tooltip)     return ToolTipPage;
-    if (cur == d->page_metadata)    return MetadataPage;
-    if (cur == d->page_template)    return TemplatePage;
-    if (cur == d->page_category)    return CategoryPage;
-    if (cur == d->page_mime)        return MimePage;
-    if (cur == d->page_lighttable)  return LightTablePage;
-    if (cur == d->page_editor)      return EditorPage;
-    if (cur == d->page_dcraw)       return DcrawPage;
-    if (cur == d->page_iofiles)     return IOFilesPage;
-    if (cur == d->page_slideshow)   return SlideshowPage;
-    if (cur == d->page_icc)         return ICCPage;
-    if (cur == d->page_plugins)     return KipiPluginsPage;
-    if (cur == d->page_camera)      return CameraPage;
-    if (cur == d->page_misc)        return MiscellaneousPage;
+    if (cur == d->page_collections)
+    {
+        return CollectionsPage;
+    }
+
+    if (cur == d->page_albumView)
+    {
+        return AlbumViewPage;
+    }
+
+    if (cur == d->page_tooltip)
+    {
+        return ToolTipPage;
+    }
+
+    if (cur == d->page_metadata)
+    {
+        return MetadataPage;
+    }
+
+    if (cur == d->page_template)
+    {
+        return TemplatePage;
+    }
+
+    if (cur == d->page_category)
+    {
+        return CategoryPage;
+    }
+
+    if (cur == d->page_mime)
+    {
+        return MimePage;
+    }
+
+    if (cur == d->page_lighttable)
+    {
+        return LightTablePage;
+    }
+
+    if (cur == d->page_editor)
+    {
+        return EditorPage;
+    }
+
+    if (cur == d->page_dcraw)
+    {
+        return DcrawPage;
+    }
+
+    if (cur == d->page_iofiles)
+    {
+        return IOFilesPage;
+    }
+
+    if (cur == d->page_slideshow)
+    {
+        return SlideshowPage;
+    }
+
+    if (cur == d->page_icc)
+    {
+        return ICCPage;
+    }
+
+    if (cur == d->page_plugins)
+    {
+        return KipiPluginsPage;
+    }
+
+    if (cur == d->page_camera)
+    {
+        return CameraPage;
+    }
+
+    if (cur == d->page_misc)
+    {
+        return MiscellaneousPage;
+    }
 
     return DatabasePage;
 }
 
 KPageWidgetItem* Setup::SetupPrivate::pageItem(Setup::Page page) const
 {
-    switch(page)
+    switch (page)
     {
         case Setup::DatabasePage:
             return page_database;
